@@ -1,19 +1,8 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2017 Kitsune Ral <kitsune-ral@users.sf.net>
+ * SPDX-FileCopyrightText: 2017 Kitsune Ral <kitsune-ral@users.sf.net>
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
@@ -41,11 +30,11 @@ class ChatEdit : public KChatEdit
 
     public slots:
         void switchContext(QObject* contextKey) override;
+        void alternatePaste();
 
     signals:
         void proposedCompletion(const QStringList& allCompletions, int curIndex);
         void cancelledCompletion();
-        void insertImageRequested(const QImage& image);
 
     protected:
         bool canInsertFromMimeData(const QMimeData* source) const override;
@@ -60,6 +49,7 @@ class ChatEdit : public KChatEdit
         int matchesListPosition;
 
         bool pickingMentions = false;
+        bool m_pastePlaintext;
 
         /// \brief Initialise a new completion
         ///
@@ -70,6 +60,7 @@ class ChatEdit : public KChatEdit
                              QUrl mentionUrl, bool select);
         void keyPressEvent(QKeyEvent* event) override;
         void contextMenuEvent(QContextMenuEvent* event) override;
+        bool pastePlaintextByDefault();
 };
 
 
