@@ -1,19 +1,8 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2015 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2015 Felix Rohrbach <kde@fxrh.de>              *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
@@ -22,29 +11,37 @@
 #include <QtWidgets/QVBoxLayout>
 #include <QtWidgets/QLabel>
 #include <QtWidgets/QToolButton>
-#include <QtWidgets/QAction>
 #include <QtWidgets/QFileDialog>
 #include <QtWidgets/QApplication>
 #include <QtGui/QClipboard>
 #include <QtGui/QTextCursor> // for last-minute message fixups before sending
 #include <QtGui/QTextDocumentFragment> // to produce plain text from /html
+#include <QtGui/QImageReader>
+
+#if QT_VERSION_MAJOR < 6
+#include <QtWidgets/QAction>
+#else
+#include <QtGui/QAction>
+#endif
 
 #include <QtCore/QRegularExpression>
 #include <QtCore/QStringBuilder>
 #include <QtCore/QLocale>
 #include <QtCore/QTemporaryFile>
 #include <QtCore/QMimeData>
+#include <QtCore/QMimeDatabase>
 
-#include <events/roommessageevent.h>
-#include <user.h>
-#include <uri.h>
-#include <settings.h>
+#include <Quotient/events/roommessageevent.h>
+#include <Quotient/user.h>
+#include <Quotient/uri.h>
+#include <Quotient/settings.h>
 
 #include "mainwindow.h"
 #include "timelinewidget.h"
 #include "quaternionroom.h"
 #include "chatedit.h"
 #include "htmlfilter.h"
+#include "logging_categories.h"
 
 static auto DefaultPlaceholderText()
 {
@@ -52,6 +49,12 @@ static auto DefaultPlaceholderText()
         "Choose a room to send messages or enter a command...");
 }
 
+static auto AttachedPlaceholderText()
+{
+    return ChatRoomWidget::tr(
+        "Add a message to the file or just push Enter");
+}
+
 static constexpr auto MaxNamesToShow = 5;
 static constexpr auto SampleSizeForHud = 3;
 Q_STATIC_ASSERT(MaxNamesToShow > SampleSizeForHud);
@@ -61,22 +64,15 @@ ChatRoomWidget::ChatRoomWidget(MainWindow* parent)
     , m_timelineWidget(new TimelineWidget(this))
     , m_uiSettings("UI")
 {
-    auto* qmlContainer =
-#ifdef DISABLE_QQUICKWIDGET
-            QWidget::createWindowContainer(m_timelineWidget, this);
-#else
-            m_timelineWidget;
-#endif // Use different objects but the same method with the same parameters
-    qmlContainer->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    m_timelineWidget->setSizePolicy(QSizePolicy::Expanding,
+                                    QSizePolicy::Expanding);
 
-    {
-        m_hudCaption = new QLabel();
-        m_hudCaption->setWordWrap(true);
-        auto f = m_hudCaption->font();
-        f.setItalic(true);
-        m_hudCaption->setFont(f);
-        m_hudCaption->setTextFormat(Qt::RichText);
-    }
+    m_hudCaption = new QLabel();
+    m_hudCaption->setWordWrap(true);
+    auto f = m_hudCaption->font();
+    f.setItalic(true);
+    m_hudCaption->setFont(f);
+    m_hudCaption->setTextFormat(Qt::RichText);
 
     auto attachButton = new QToolButton();
     attachButton->setAutoRaise(true);
@@ -84,60 +80,33 @@ ChatRoomWidget::ChatRoomWidget(MainWindow* parent)
                                  tr("Attach"), attachButton);
     m_attachAction->setCheckable(true);
     m_attachAction->setDisabled(true);
-    connect(m_attachAction, &QAction::triggered, this, [this] (bool checked) {
-        if (checked)
-        {
-            attachedFileName =
+    connect(m_attachAction, &QAction::triggered, this, [this](bool checked) {
+        auto statusMessage = tr("Attaching cancelled");
+        if (checked) {
+            if (const auto filePath =
                     QFileDialog::getOpenFileName(this, tr("Attach file"));
-        } else {
-            if (m_fileToAttach->isOpen())
-                m_fileToAttach->remove();
-            attachedFileName.clear();
-        }
-
-        if (!attachedFileName.isEmpty())
-        {
-            m_chatEdit->setPlaceholderText(
-                tr("Add a message to the file or just push Enter"));
-            mainWindow()->showStatusMessage(
-                tr("Attaching %1").arg(attachedFileName));
-        } else {
-            m_attachAction->setChecked(false);
-            m_chatEdit->setPlaceholderText(DefaultPlaceholderText());
-            mainWindow()->showStatusMessage(tr("Attaching cancelled"), 3000);
+                !filePath.isEmpty()
+                && (statusMessage  = attachFile(filePath)).isEmpty())
+                return;
         }
+        cancelAttaching();
+        m_chatEdit->setPlaceholderText(DefaultPlaceholderText());
+        mainWindow()->showStatusMessage(statusMessage , 3000);
     });
     attachButton->setDefaultAction(m_attachAction);
 
-    m_fileToAttach = new QTemporaryFile(this);
-
     m_chatEdit = new ChatEdit(this);
     m_chatEdit->setPlaceholderText(DefaultPlaceholderText());
     m_chatEdit->setAcceptRichText(true); // m_uiSettings.get("rich_text_editor", false);
     m_chatEdit->setMaximumHeight(maximumChatEditHeight());
     connect(m_chatEdit, &KChatEdit::returnPressed, this,
             &ChatRoomWidget::sendInput);
-    connect(m_chatEdit, &KChatEdit::copyRequested, this, [=] {
+    connect(m_chatEdit, &KChatEdit::copyRequested, this, [this] {
         QApplication::clipboard()->setText(
             m_chatEdit->textCursor().hasSelection()
                 ? m_chatEdit->textCursor().selectedText()
                 : m_timelineWidget->selectedText());
     });
-    connect(m_chatEdit, &ChatEdit::insertImageRequested, this,
-            [=](const QImage& image) {
-                if (currentRoom() == nullptr || m_fileToAttach->isOpen())
-                    return;
-
-                m_fileToAttach->open();
-                image.save(m_fileToAttach, "PNG");
-
-                attachedFileName = m_fileToAttach->fileName();
-                m_attachAction->setChecked(true);
-                m_chatEdit->setPlaceholderText(
-                    tr("Add a message to the file or just push Enter"));
-                mainWindow()->showStatusMessage(
-                    tr("Attaching an image from clipboard"));
-            });
     connect(m_chatEdit, &ChatEdit::proposedCompletion, this,
             [this](QStringList matches, int pos) {
                 Q_ASSERT(pos >= 0 && pos < matches.size());
@@ -188,7 +157,7 @@ ChatRoomWidget::ChatRoomWidget(MainWindow* parent)
     }
 
     auto* layout = new QVBoxLayout();
-    layout->addWidget(qmlContainer);
+    layout->addWidget(m_timelineWidget);
     layout->addWidget(m_hudCaption);
     {
         auto inputLayout = new QHBoxLayout;
@@ -225,10 +194,7 @@ void ChatRoomWidget::setRoom(QuaternionRoom* newRoom)
         currentRoom()->connection()->disconnect(this);
         currentRoom()->disconnect(this);
     }
-    attachedFileName.clear();
-    m_attachAction->setChecked(false);
-    if (m_fileToAttach->isOpen())
-        m_fileToAttach->remove();
+    cancelAttaching();
 
     m_timelineWidget->setRoom(newRoom);
     m_attachAction->setEnabled(newRoom != nullptr);
@@ -241,7 +207,7 @@ void ChatRoomWidget::setRoom(QuaternionRoom* newRoom)
         connect(newRoom, &Room::encryption, //
                 this, &ChatRoomWidget::encryptionChanged);
         connect(newRoom->connection(), &Connection::loggedOut, this, [this] {
-            qWarning() << "Logged out, escaping the room";
+            qCWarning(MSGINPUT) << "Logged out, escaping the room";
             setRoom(nullptr);
         });
     }
@@ -277,12 +243,9 @@ void ChatRoomWidget::encryptionChanged()
 {
     m_chatEdit->setPlaceholderText(
         currentRoom()
-            ? currentRoom()->usesEncryption()
-                ? tr("Send a message (no end-to-end encryption support yet)...")
-                : tr("Send a message (over %1) or enter a command...",
-                     "%1 is the protocol used by the server (usually HTTPS)")
-                  .arg(currentRoom()->connection()->homeserver()
-                       .scheme().toUpper())
+            ? tr("Send a message (over %1) or enter a command...",
+                 "%1 is the protocol used by the server (usually HTTPS)")
+                  .arg(currentRoom()->connection()->homeserver().scheme().toUpper())
             : DefaultPlaceholderText());
 }
 
@@ -330,6 +293,71 @@ void ChatRoomWidget::insertMention(Quotient::User* user)
     m_chatEdit->setFocus();
 }
 
+void ChatRoomWidget::attachImage(const QImage& img, const QList<QUrl>& sources)
+{
+    if (currentRoom() == nullptr)
+        return;
+
+    // TODO:
+    // 3. If the URL is local, detect the MIME type and the suffix
+    // 4. Otherwise, prepend "image/" to the format string in QImage
+    //    and derive the suffix from this string
+    const auto tempFileName = sources.size() == 1
+                                      && sources.front().isLocalFile()
+                                  ? sources.front().fileName()
+                                  : QStringLiteral("image.XXXXXX.png");
+    m_fileToAttach = std::make_unique<QTemporaryFile>(tempFileName);
+    img.save(m_fileToAttach.get());
+
+    m_attachAction->setChecked(true);
+    m_chatEdit->setPlaceholderText(AttachedPlaceholderText());
+    mainWindow()->showStatusMessage(tr("Attaching the pasted image"));
+    // TODO, 0.0.97: tr("... from %1").arg(localPath)
+}
+
+QString ChatRoomWidget::attachFile(const QString& localPath)
+{
+    Q_ASSERT(currentRoom() != nullptr);
+
+    qCDebug(MSGINPUT) << "Trying to attach" << localPath;
+    m_fileToAttach = std::make_unique<QFile>(localPath);
+    if (const auto error = checkAttachment(); !error.isEmpty())
+        return error;
+
+    m_chatEdit->setPlaceholderText(AttachedPlaceholderText());
+    mainWindow()->showStatusMessage(
+        tr("Attaching %1").arg(m_fileToAttach->fileName()));
+    return {};
+}
+
+void ChatRoomWidget::dropFile(const QString& localPath)
+{
+    if (const auto error = attachFile(localPath); !error.isEmpty())
+        mainWindow()->showStatusMessage(error, 3000);
+    else
+        m_attachAction->setChecked(true);
+}
+
+QString ChatRoomWidget::checkAttachment()
+{
+    Q_ASSERT(m_fileToAttach != nullptr);
+    if (m_fileToAttach->isReadable()
+        || m_fileToAttach->open(QIODevice::ReadOnly))
+        return {};
+
+    // Form the message in advance while the file name is still there
+    const auto msg =
+        tr("%1 is not readable or not a file").arg(m_fileToAttach->fileName());
+    cancelAttaching();
+    return msg;
+}
+
+void ChatRoomWidget::cancelAttaching()
+{
+    m_fileToAttach.reset();
+    m_attachAction->setChecked(false);
+}
+
 void ChatRoomWidget::focusInput()
 {
     m_chatEdit->setFocus();
@@ -360,43 +388,59 @@ QVector<QString> lazySplitRef(const QString& s, QChar sep, int maxParts)
     return parts;
 }
 
-void ChatRoomWidget::sendFile()
+Quotient::EventContent::TypedBase* contentFromFile(const QFileInfo& file)
+{
+    using namespace Quotient::EventContent;
+    auto filePath = file.absoluteFilePath();
+    auto localUrl = QUrl::fromLocalFile(filePath);
+    auto mimeType = QMimeDatabase().mimeTypeForFile(file);
+
+    auto mimeTypeName = mimeType.name();
+    if (mimeTypeName.startsWith("image/"))
+        return new ImageContent(localUrl, file.size(), mimeType,
+                                QImageReader(filePath).size(), file.fileName());
+
+    if (mimeTypeName.startsWith("audio/"))
+        return new AudioContent(localUrl, file.size(), mimeType,
+                                file.fileName());
+
+    // TODO: video files support
+
+    return new FileContent(localUrl, file.size(), mimeType, file.fileName());
+}
+
+QString ChatRoomWidget::sendFile()
 {
     Q_ASSERT(currentRoom() != nullptr);
     const auto& description = m_chatEdit->toPlainText();
-    auto txnId = currentRoom()->postFile(description.isEmpty()
-                                             ? QUrl(attachedFileName).fileName()
-                                             : description,
-                                         QUrl::fromLocalFile(attachedFileName));
+    if (const auto error = checkAttachment(); !error.isEmpty())
+        return error;
 
-    if (m_fileToAttach->isOpen())
-        m_fileToAttach->remove();
-    attachedFileName.clear();
-    m_attachAction->setChecked(false);
-    m_chatEdit->setPlaceholderText(DefaultPlaceholderText());
+    QFileInfo fileInfo(*m_fileToAttach);
+    currentRoom()->postFile(description.isEmpty() ? fileInfo.fileName()
+                                                  : description,
+                            contentFromFile(fileInfo));
+    cancelAttaching();
+    return {};
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 void sendMarkdown(QuaternionRoom* room, const QTextDocumentFragment& text)
 {
     room->postHtmlText(text.toPlainText(),
                        HtmlFilter::toMatrixHtml(text.toHtml(), room,
                                                 HtmlFilter::ConvertMarkdown));
 }
-#endif
 
 void ChatRoomWidget::sendMessage()
 {
     if (m_chatEdit->toPlainText().startsWith("//"))
         QTextCursor(m_chatEdit->document()).deleteChar();
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     if (m_uiSettings.get("auto_markdown", false)) {
         sendMarkdown(currentRoom(),
                      QTextDocumentFragment(m_chatEdit->document()));
         return;
     }
-#endif
     const auto& plainText = m_chatEdit->toPlainText();
     const auto& htmlText =
         HtmlFilter::toMatrixHtml(m_chatEdit->toHtml(), currentRoom());
@@ -415,7 +459,7 @@ static auto NothingToSendMsg()
     return ChatRoomWidget::tr("There's nothing to send");
 }
 
-QString ChatRoomWidget::sendCommand(const QStringRef& command,
+QString ChatRoomWidget::sendCommand(QStringView command,
                                     const QString& argString)
 {
     static const auto ReFlags = QRegularExpression::DotMatchesEverythingOption
@@ -436,14 +480,14 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
     Q_ASSERT(RoomIdRE.isValid() && UserIdRE.isValid());
 
     // Commands available without a current room
-    if (command == "join")
+    if (command == u"join")
     {
         if (!argString.contains(RoomIdRE))
             return tr("/join argument doesn't look like a room ID or alias");
         mainWindow()->openResource(argString, "join");
         return {};
     }
-    if (command == "quit")
+    if (command == u"quit")
     {
         qApp->closeAllWindows();
         return {};
@@ -456,7 +500,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
 
     // Commands available only in the room context
     using namespace Quotient;
-    if (command == "leave" || command == "part")
+    if (command == u"leave" || command == u"part")
     {
         if (!argString.isEmpty())
             return tr("Sending a farewell message is not supported yet."
@@ -466,7 +510,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         currentRoom()->leaveRoom();
         return {};
     }
-    if (command == "forget")
+    if (command == u"forget")
     {
         if (argString.isEmpty())
             return tr("/forget must be followed by the room id/alias,"
@@ -478,7 +522,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         currentRoom()->connection()->forgetRoom(argString);
         return {};
     }
-    if (command == "invite")
+    if (command == u"invite")
     {
         if (argString.isEmpty())
             return tr("/invite <memberId>");
@@ -488,7 +532,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         currentRoom()->inviteToRoom(argString);
         return {};
     }
-    if (command == "kick" || command == "ban")
+    if (command == u"kick" || command == u"ban")
     {
         const auto args = lazySplitRef(argString, ' ', 2);
         if (args.front().isEmpty())
@@ -497,18 +541,18 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
             return tr("%1 doesn't look like a user id")
                     .arg(args.front());
 
-        if (command == "ban")
+        if (command == u"ban")
             currentRoom()->ban(args.front(), args.back());
         else {
-            auto* const user = currentRoom()->user(args.front());
-            if (currentRoom()->memberJoinState(user) != JoinState::Join)
-                return tr("%1 is not a member of this room")
-                    .arg(user ? user->fullName(currentRoom()) : args.front());
-            currentRoom()->kickMember(user->id(), args.back());
+            const auto& userId = args.front();
+            if (!currentRoom()->isMember(userId))
+                return tr("%1 is not a member of this room").arg(userId);
+
+            currentRoom()->kickMember(userId, args.back());
         }
         return {};
     }
-    if (command == "unban")
+    if (command == u"unban")
     {
         if (argString.isEmpty())
             return tr("/unban <userId>");
@@ -518,7 +562,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         currentRoom()->unban(argString);
         return {};
     }
-    if (command == "ignore" || command == "unignore")
+    if (command == u"ignore" || command == u"unignore")
     {
         if (argString.isEmpty())
             return tr("/ignore <userId>");
@@ -527,7 +571,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
 
         if (auto* user = currentRoom()->user(argString))
         {
-            if (command == "ignore")
+            if (command == u"ignore")
                 user->ignore();
             else
                 user->unmarkIgnore();
@@ -536,52 +580,53 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         return tr("Couldn't find user %1 on the server").arg(argString);
     }
     using MsgType = RoomMessageEvent::MsgType;
-    if (command == "me")
+    if (command == u"me")
     {
         if (argString.isEmpty())
             return tr("/me needs an argument");
         currentRoom()->postMessage(argString, MsgType::Emote);
         return {};
     }
-    if (command == "notice")
+    if (command == u"notice")
     {
         if (argString.isEmpty())
             return tr("/notice needs an argument");
         currentRoom()->postMessage(argString, MsgType::Notice);
         return {};
     }
-    if (command == "shrug") // Peeked at Discord
+    if (command == u"shrug") // Peeked at Discord
     {
         currentRoom()->postPlainText((argString.isEmpty() ? "" : argString + " ") +
                                      "¯\\_(ツ)_/¯");
         return {};
     }
-    if (command == "roomname")
+    if (command == u"roomname")
     {
         currentRoom()->setName(argString);
         return {};
     }
-    if (command == "topic")
+    if (command == u"topic")
     {
         currentRoom()->setTopic(argString);
         return {};
     }
-    if (command == "nick" || command == "mynick")
+    if (command == u"nick" || command == u"mynick")
     {
         currentRoom()->localUser()->rename(argString);
         return {};
     }
-    if (command == "roomnick" || command == "myroomnick")
+    if (command == u"roomnick" || command == u"myroomnick")
     {
         currentRoom()->localUser()->rename(argString, currentRoom());
         return {};
     }
-    if (command == "pm" || command == "msg")
+    if (command == u"pm" || command == u"msg")
     {
         const auto args = lazySplitRef(argString, ' ', 2);
-        if (args.front().isEmpty() || (args.back().isEmpty() && command == "msg"))
+        if (args.front().isEmpty()
+            || (args.back().isEmpty() && command == u"msg"))
             return tr("/%1 <memberId> <message>").arg(command.toString());
-        if (RoomIdRE.match(args.front()).hasMatch() && command == "msg")
+        if (RoomIdRE.match(args.front()).hasMatch() && command == u"msg")
         {
             if (auto* room = currentRoom()->connection()->room(args.front()))
             {
@@ -604,7 +649,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         return tr("%1 doesn't look like a user id or room alias")
                 .arg(args.front());
     }
-    if (command == "plain") {
+    if (command == u"plain") {
         // argString eats away leading spaces, so can't be used here
         static const auto CmdLen = QStringLiteral("/plain ").size();
         const auto& plainMsg = m_chatEdit->toPlainText().mid(CmdLen);
@@ -613,7 +658,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         currentRoom()->postPlainText(plainMsg);
         return {};
     }
-    if (command == "html")
+    if (command == u"html")
     {
         // Assuming Matrix HTML, convert it to Qt and load to a fragment in
         // order to produce a plain text version (maybe introduce
@@ -634,8 +679,7 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
                                                              currentRoom()));
         return {};
     }
-    if (command == "md") {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+    if (command == u"md") {
         // Select everything after /md and one whitespace character after it
         // (leading whitespaces have meaning in Markdown)
         QTextCursor c(m_chatEdit->document());
@@ -643,11 +687,8 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         c.movePosition(QTextCursor::End, QTextCursor::KeepAnchor);
         sendMarkdown(currentRoom(), c.selection());
         return {};
-#else
-        return tr("Your build of Quaternion doesn't support Markdown");
-#endif
     }
-    if (command == "query" || command == "dc")
+    if (command == u"query" || command == u"dc")
     {
         if (argString.isEmpty())
             return tr("/%1 <memberId>").arg(command.toString());
@@ -658,36 +699,37 @@ QString ChatRoomWidget::sendCommand(const QStringRef& command,
         return {};
     }
     // --- Add more room commands here
-    qDebug() << "Unknown command:" << command;
+    qCDebug(MSGINPUT) << "Unknown command:" << command;
     return tr("Unknown /command. Use // to send this line literally");
 }
 
 void ChatRoomWidget::sendInput()
 {
-    if (!attachedFileName.isEmpty())
-        sendFile();
+    QString error;
+    if (m_fileToAttach)
+        error = sendFile();
     else {
         const auto& text = m_chatEdit->toPlainText();
-        QString error;
         if (text.isEmpty())
             error = NothingToSendMsg();
-        else if (text.startsWith('/') && !text.midRef(1).startsWith('/')) {
+        else if (text.startsWith('/')
+                 && !QStringView(text).mid(1).startsWith('/')) {
             QRegularExpression cmdSplit(
                     "(\\w+)(?:\\s+(.*))?",
                     QRegularExpression::DotMatchesEverythingOption);
             const auto& blanksMatch = cmdSplit.match(text, 1);
-            error = sendCommand(blanksMatch.capturedRef(1),
+            error = sendCommand(blanksMatch.capturedView(1),
                                 blanksMatch.captured(2));
         } else if (!currentRoom())
             error = tr("You should select a room to send messages.");
         else
             sendMessage();
-        if (!error.isEmpty()) {
-            mainWindow()->showStatusMessage(error, 5000);
-            return;
-        }
     }
-
+    if (!error.isEmpty()) {
+        mainWindow()->showStatusMessage(error, 5000);
+        return;
+    }
+    m_chatEdit->setPlaceholderText(DefaultPlaceholderText());
     m_chatEdit->saveInput();
 }
 
@@ -770,27 +812,3 @@ int ChatRoomWidget::maximumChatEditHeight() const
 {
     return height() / 3;
 }
-
-void ChatRoomWidget::fileDrop(const QString& url)
-{
-    attachedFileName = QUrl(url).path();
-    m_attachAction->setChecked(true);
-    m_chatEdit->setPlaceholderText(
-        tr("Add a message to the file or just push Enter"));
-    mainWindow()->showStatusMessage(tr("Attaching %1").arg(attachedFileName));
-}
-
-void ChatRoomWidget::htmlDrop(const QString &html)
-{
-    m_chatEdit->insertHtml(html);
-}
-
-void ChatRoomWidget::textDrop(const QString& text)
-{
-    m_chatEdit->insertPlainText(text);
-}
-
-Qt::KeyboardModifiers ChatRoomWidget::getModifierKeys() const
-{
-    return QGuiApplication::keyboardModifiers();
-}
