@@ -1,19 +1,8 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2015 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2015 Felix Rohrbach <kde@fxrh.de>              *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
@@ -21,8 +10,9 @@
 
 #include "chatedit.h"
 
-#include <settings.h>
+#include <Quotient/settings.h>
 
+#include <QtCore/QTemporaryFile>
 #include <QtWidgets/QWidget>
 
 class TimelineWidget;
@@ -31,9 +21,6 @@ class MainWindow;
 
 class QLabel;
 class QAction;
-class QTextDocument;
-class QMimeData;
-class QTemporaryFile;
 
 namespace Quotient {
 class User;
@@ -49,11 +36,15 @@ class ChatRoomWidget : public QWidget
         TimelineWidget* timelineWidget() const;
 
         completions_t findCompletionMatches(const QString& pattern) const;
-        Q_INVOKABLE Qt::KeyboardModifiers getModifierKeys() const;
 
     public slots:
         void setRoom(QuaternionRoom* newRoom);
         void insertMention(Quotient::User* user);
+        void attachImage(const QImage& img, const QList<QUrl>& sources);
+        QString attachFile(const QString& localPath);
+        void dropFile(const QString& localPath);
+        QString checkAttachment();
+        void cancelAttaching();
         void focusInput();
 
         /// Set a line just above the message input, with optional list of
@@ -63,9 +54,6 @@ class ChatRoomWidget : public QWidget
 
         void typingChanged();
         void quote(const QString& htmlText);
-        void fileDrop(const QString& url);
-        void htmlDrop(const QString& html);
-        void textDrop(const QString& text);
 
     private slots:
         void sendInput();
@@ -73,20 +61,19 @@ class ChatRoomWidget : public QWidget
 
     private:
         TimelineWidget* m_timelineWidget;
-        QLabel* m_hudCaption; //< For typing and completion notifications
+        QLabel* m_hudCaption; //!< For typing and completion notifications
         QAction* m_attachAction;
         ChatEdit* m_chatEdit;
 
-        QString attachedFileName;
-        QTemporaryFile* m_fileToAttach;
+        std::unique_ptr<QFile> m_fileToAttach;
         Quotient::SettingsGroup m_uiSettings;
 
         MainWindow* mainWindow() const;
         QuaternionRoom* currentRoom() const;
 
-        void sendFile();
+        QString sendFile();
         void sendMessage();
-        [[nodiscard]] QString sendCommand(const QStringRef& command,
+        [[nodiscard]] QString sendCommand(QStringView command,
                                           const QString& argString);
 
         void resizeEvent(QResizeEvent*) override;
