@@ -1,8 +1,11 @@
 #include "htmlfilter.h"
 
-#include <util.h>
+#include "logging_categories.h"
+
+#include <Quotient/util.h>
 
 #include <QtGui/QTextDocument>
+#include <QtGui/QFontDatabase>
 
 #include <QtCore/QRegularExpression>
 #include <QtCore/QXmlStreamReader>
@@ -40,44 +43,46 @@ private:
 
     using rewrite_t = vector<pair<QString, QXmlStreamAttributes>>;
 
-    [[nodiscard]] rewrite_t filterTag(const QStringRef& tag,
+    [[nodiscard]] rewrite_t filterTag(QStringView tag,
                                       QXmlStreamAttributes attributes);
     void filterText(QString& text);
 };
 
-static const QString permittedTags[] = {
-    "font",       "del", "h1",    "h2",     "h3",      "h4",     "h5",   "h6",
-    "blockquote", "p",   "a",     "ul",     "ol",      "sup",    "sub",  "li",
-    "b",          "i",   "u",     "strong", "em",      "strike", "code", "hr",
-    "br",         "div", "table", "thead",  "tbody",   "tr",     "th",   "td",
-    "caption",    "pre", "span",  "img",    "mx-reply"
+static const QStringView permittedTags[] = {
+    u"font",   u"del",        u"h1", u"h2", u"h3",      u"h4",     u"h5",
+    u"h6",     u"blockquote", u"p",  u"a",  u"ul",      u"ol",     u"sup",
+    u"sub",    u"li",         u"b",  u"i",  u"u",       u"strong", u"em",
+    u"strike", u"code",       u"hr", u"br", u"div",     u"table",  u"thead",
+    u"tbody",  u"tr",         u"th", u"td", u"caption", u"pre",    u"span",
+    u"img",    u"mx-reply"
 };
 
 struct PassList {
-    const char* tag;
-    vector<const char*> allowedAttrs;
+    QStringView tag;
+    vector<QStringView> allowedAttrs;
 };
 
 // See filterTag() on special processing of commented out tags/attributes
 static const PassList passLists[] = {
-    { "a", { "name", "target", /* "href" - only from permittedSchemes */ } },
-    { "img", { "width", "height", "alt", "title", "data-mx-emoticon"
+    { u"a", { u"name", u"target", /* "href" - only from permittedSchemes */ } },
+    { u"img", { u"width", u"height", u"alt", u"title", u"data-mx-emoticon"
                /* "src" - only 'mxc:' */ } },
-    { "ol", { "start" } },
-    { "font", { "color", "data-mx-color", "data-mx-bg-color" } },
-    { "span", { "color", "data-mx-color", "data-mx-bg-color" } }
+    { u"ol", { u"start" } },
+    { u"font", { u"color", u"data-mx-color", u"data-mx-bg-color" } },
+    { u"span", { u"color", u"data-mx-color", u"data-mx-bg-color" } }
     //, { "code", { "class" /* must start with 'language-' */ } } // Special case
 };
 
-static const char* const permittedSchemes[] { "http:",   "https:",  "ftp:",
-                                              "mailto:", "magnet:", "matrix:" };
+static QStringView const permittedSchemes[]{
+    u"http:",   u"https:",  u"ftp:", u"mailto:",
+    u"magnet:", u"matrix:", u"mxc:" /* MSC2398 */
+};
 
-static const auto& htmlColorAttr = QStringLiteral("color");
-static const auto& htmlStyleAttr = QStringLiteral("style");
-static const auto& mxColorAttr = QStringLiteral("data-mx-color");
-static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
+static const auto htmlColorAttr = u"color";
+static const auto htmlStyleAttr = u"style";
+static const auto mxColorAttr = u"data-mx-color";
+static const auto mxBgColorAttr = u"data-mx-bg-color";
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
 [[nodiscard]] QString mergeMarkdown(const QString& html)
 {
     // This code intends to merge user-entered Markdown+HTML markup
@@ -91,10 +96,10 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
     QString mdWithHtml;
     QXmlStreamWriter writer(&mdWithHtml);
     while (reader.readNext() != QXmlStreamReader::StartElement
-           || reader.qualifiedName() != "p")
+               || reader.qualifiedName() != u"p")
         if (reader.atEnd()) {
             Q_ASSERT_X(false, __FUNCTION__, "Malformed Qt markup");
-            qCritical()
+            qCCritical(HTMLFILTER)
                 << "The passed text doesn't seem to come from QTextDocument";
             return {};
         }
@@ -119,7 +124,7 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
 
         case QXmlStreamReader::StartElement:
             ++depth;
-            if (reader.qualifiedName() != "p")
+            if (reader.qualifiedName() != u"p")
                 break;
             // Convert <p> elements except the first one
             // to Markdown paragraph breaks
@@ -127,17 +132,17 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
             continue;
         case QXmlStreamReader::EndElement:
             --depth;
-            if (reader.qualifiedName() == "p")
+            if (reader.qualifiedName() == u"p")
                 continue; // See above in StartElement
             break;
         case QXmlStreamReader::Comment:
             continue; // Just drop comments
         default:
-            qWarning() << "Unexpected token, type" << tokenType;
+            qCWarning(HTMLFILTER) << "Unexpected token, type" << tokenType;
         }
         if (depth < 0) {
             Q_ASSERT(tokenType == QXmlStreamReader::EndElement
-                     && reader.qualifiedName() == "body");
+                     && reader.qualifiedName() == u"body");
             break;
         }
         writer.writeCurrentToken(reader);
@@ -147,7 +152,6 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
     doc.setMarkdown(mdWithHtml);
     return doc.toHtml();
 }
-#endif
 
 [[nodiscard]] inline bool isTagNameTerminator(QChar c)
 {
@@ -168,11 +172,11 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
 [[nodiscard]] Result preprocess(QString html, Mode mode, Options options)
 {
     Q_ASSERT(mode != QtToMatrix);
-    bool isFragment = mode == MatrixToQt;
+    bool isFragment = options.testFlag(Fragment) || mode == MatrixToQt;
     bool inHead = false;
     for (auto pos = html.indexOf('<'); pos != -1; pos = html.indexOf('<', pos)) {
         const auto tagNamePos = pos + 1 + (html[pos + 1] == '/');
-        const auto uncheckedHtml = html.midRef(tagNamePos);
+        const QStringView uncheckedHtml = QStringView(html).mid(tagNamePos);
         static const QLatin1String commentOpen("!--");
         static const QLatin1String commentClose("-->");
         if (uncheckedHtml.startsWith(commentOpen)) { // Skip comments
@@ -191,7 +195,7 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
             pos += to.size(); // Put pos after the escaped sequence
             continue;
         }
-        if (uncheckedHtml.startsWith("head>", Qt::CaseInsensitive)) {
+        if (uncheckedHtml.startsWith(u"head>", Qt::CaseInsensitive)) {
             if (mode == MatrixToQt) {
                 // Matrix spec doesn't allow <head>; report if it occurs in
                 // user input (Validate is on) or remove the whole header if
@@ -224,8 +228,8 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
         // neither `head` nor tags inside of it are in permittedTags;
         // however, minimised attributes still have to be handled everywhere
         // and <meta> tags should be closed
-        if (mode == GenericToQt && tag == "html") {
-            // Only in generic mode, allow <html> element
+        if (mode == GenericToQt && (tag == u"html" || tag == u"body")) {
+            // Only in generic mode, allow <html> and <body>
             pos += tagNamePos + tag.size() + 1;
             isFragment = false;
             continue;
@@ -287,6 +291,8 @@ static const auto& mxBgColorAttr = QStringLiteral("data-mx-bg-color");
     // possibly with generic HTML).
     if (isFragment)
         html = "<span>" % html % "</span>";
+    // Discard characters behind the last tag (LibreOffice attaches \n\0, e.g.)
+    html.truncate(html.lastIndexOf('>') + 1);
     return { html };
 }
 
@@ -309,27 +315,23 @@ Result Processor::process(QString html, Mode mode, QuaternionRoom* context,
     // characters.
 
     // 1. Escape ampersands outside of character entities
-    html.replace(QRegularExpression("&(?!(#[0-9]+" // clang-format off
-                                        "|#x[0-9a-fA-F]+"
-                                        "|[[:alpha:]_][-[:alnum:]_:.]*"
-                                    ");)"), // clang-format on
-                 "&amp;");
+    static const QRegularExpression freestandingAmps{ QStringLiteral(
+        "&(?!(#[0-9]+|#x[0-9a-fA-F]+|[[:alpha:]_][-[:alnum:]_:.]*);)") };
+    html.replace(freestandingAmps, QStringLiteral("&amp;"));
 
     if (mode == QtToMatrix) {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
         if (options.testFlag(ConvertMarkdown)) {
             // The processor handles Markdown in chunks between HTML tags;
             // <br /> breaks character sequences that are otherwise valid
             // Markdown, leading to issues with, e.g., lists.
-            html.replace("<br />", QStringLiteral("\n"));
-#    if 0
-        html = mergeMarkdown(html);
-        if (html.isEmpty())
-            return { "", 0, "This markup doesn't seem to be sourced from Qt" };
-        options &= ~ConvertMarkdown;
-#    endif
-        }
+            html.replace(QStringLiteral("<br />"), QStringLiteral("\n"));
+#if 0
+            html = mergeMarkdown(html);
+            if (html.isEmpty())
+                return { "", 0, "This markup doesn't seem to be sourced from Qt" };
+            options &= ~ConvertMarkdown;
 #endif
+        }
     } else {
         auto r = preprocess(html, mode, options);
         if (r.errorPos != -1)
@@ -342,7 +344,7 @@ Result Processor::process(QString html, Mode mode, QuaternionRoom* context,
     writer.setAutoFormatting(false);
     Processor p { mode, options, context, writer };
     p.runOn(html);
-    return { resultHtml, p.errorPos, p.errorString };
+    return { resultHtml.trimmed(), p.errorPos, p.errorString };
 }
 
 QString toMatrixHtml(const QString& qtMarkup, QuaternionRoom* context,
@@ -359,10 +361,8 @@ QString toMatrixHtml(const QString& qtMarkup, QuaternionRoom* context,
 Result fromMatrixHtml(const QString& matrixHtml, QuaternionRoom* context,
                       Options options)
 {
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     // Matrix HTML body should never be treated as Markdown
     Q_ASSERT(!options.testFlag(ConvertMarkdown));
-#endif
     auto result = Processor::process(matrixHtml, MatrixToQt, context, options);
     if (result.errorPos == -1) {
         // Make sure to preserve whitespace sequences
@@ -378,9 +378,25 @@ Result fromLocalHtml(const QString& html,
     return Processor::process(html, GenericToQt, context, options);
 }
 
+namespace {
+    class EntityResolver : public QXmlStreamEntityResolver {
+    public:
+        using QXmlStreamEntityResolver::QXmlStreamEntityResolver;
+        Q_DISABLE_COPY_MOVE(EntityResolver)
+
+    private:
+        QString resolveUndeclaredEntity(const QString& name) override
+        {
+            return name == u"nbsp" ? QStringLiteral("\xa0") : QString();
+        }
+    };
+    EntityResolver entityResolver;
+}
+
 void Processor::runOn(const QString &html)
 {
     QXmlStreamReader reader(html);
+    reader.setEntityResolver(&entityResolver);
 
     /// The entry in the (outer) stack corresponds to each level in the source
     /// document; the (inner) stack in each entry records open elements in the
@@ -393,20 +409,12 @@ void Processor::runOn(const QString &html)
     /// text parts.
     QString textBuffer;
     int bodyOffset = 0;
-    bool firstElement = true, inAnchor = false, inHead = false;
+    bool firstElement = true, inAnchor = false;
     while (!reader.atEnd()) {
         const auto tokenType = reader.readNext();
         if (bodyOffset == -1) // See below in 'case StartElement:'
             bodyOffset = reader.characterOffset();
 
-        if (inHead) {
-            writer.writeCurrentToken(reader);
-            if (tokenType == QXmlStreamReader::EndElement
-                && reader.qualifiedName() == "head") {
-                inHead = false;
-            }
-            continue;
-        }
         if (!textBuffer.isEmpty() && !reader.isCharacters()
             && !reader.isEntityReference())
             filterText(textBuffer);
@@ -417,19 +425,40 @@ void Processor::runOn(const QString &html)
             if (tagsStack.empty()) {
                 // These tags are invalid anywhere deeper, and we don't even
                 // care to put them to tagsStack
-                if (tagName == "html")
-                    break; // Just ignore, get to the content inside
-                if (tagName == "head") {
-                    if (mode == GenericToQt) {
-                        inHead = true;
+                if (tagName == u"html") {
+                    if (mode == GenericToQt)
                         writer.writeCurrentToken(reader);
-                        continue;
-                    }
-                    reader.skipCurrentElement(); // Entirely uninteresting
-                    break;
+                    break; // Otherwise, just ignore, get to the content inside
                 }
-                if (tagName == "body") { // Skip but note the encounter
-                    bodyOffset = -1; // Reuse the variable until the next loop
+                if (tagName == u"head") {
+                    // <head> is only needed for Qt to import HTML more
+                    // accurately, and entirely uninteresting in other modes
+                    if (mode != GenericToQt) {
+                        reader.skipCurrentElement();
+                        break;
+                    }
+                    // Copy through the whole <head> element - having
+                    // QXmlStreamWriter::writeCurrentElement() would help
+                    // but there's none such
+                    do {
+                        writer.writeCurrentToken(reader);
+                        const auto nextTokenType = reader.readNext();
+                        if (nextTokenType == QXmlStreamReader::EndElement
+                            && reader.qualifiedName() == u"head") {
+                            writer.writeCurrentToken(reader);
+                            break;
+                        }
+                    } while (!reader.atEnd());
+                    continue;
+                }
+                if (tagName == u"body") {
+                    if (mode == GenericToQt)
+                        writer.writeCurrentToken(reader);
+                    // Except importing HTML into QTextDocument, skip just like
+                    // <html> but record the position for error reporting
+                    // (FIXME: this position is still not exactly related to
+                    // the original text...)
+                    bodyOffset = -1; // See the end of the while loop
                     break;
                 }
             }
@@ -437,9 +466,9 @@ void Processor::runOn(const QString &html)
             const auto& attrs = reader.attributes();
             if (find_if(attrs.cbegin(), attrs.cend(),
                         [](const auto& a) {
-                            return a.qualifiedName() == "style"
+                            return a.qualifiedName() == u"style"
                                    && a.value().contains(
-                                       "-qt-paragraph-type:empty");
+                                       u"-qt-paragraph-type:empty");
                         })
                 != attrs.cend()) {
                 reader.skipCurrentElement();
@@ -448,7 +477,8 @@ void Processor::runOn(const QString &html)
 
             tagsStack.emplace();
             if (tagsStack.size() > 100)
-                qCritical() << "CS API spec limits HTML tags depth at 100";
+                qCCritical(HTMLFILTER)
+                    << "CS API spec limits HTML tags depth at 100";
 
             // Qt hardcodes the link style in a `<span>` under `<a>`.
             // This breaks the looks on the receiving side if the sender
@@ -456,8 +486,8 @@ void Processor::runOn(const QString &html)
             // Since Qt decorates links when importing HTML anyway, we
             // don't lose anything if we just strip away this span tag.
             if (mode != MatrixToQt && inAnchor && textBuffer.isEmpty()
-                && tagName == "span" && attrs.size() == 1
-                && attrs.front().qualifiedName() == "style")
+                && tagName == u"span" && attrs.size() == 1
+                && attrs.front().qualifiedName() == u"style")
                 continue; // inAnchor == true ==> firstElement == false
 
             // Skip the first top-level <p> and replace further top-level
@@ -469,23 +499,23 @@ void Processor::runOn(const QString &html)
             // e.g.). This is also a very special case where a converted tag
             // is immediately closed, unlike the one in the source text;
             // which is why it's checked here rather than in filterTag().
-            if (mode == QtToMatrix && tagName == "p"
+            if (mode == QtToMatrix && tagName == u"p"
                 && tagsStack.size() == 1 /* top-level, just emplaced */) {
                 if (firstElement)
                     continue; // Skip unsetting firstElement at the loop end
                 writer.writeEmptyElement("br");
                 break;
             }
-            if (tagName != "mx-reply"
+            if (tagName != u"mx-reply"
                 || (firstElement && !options.testFlag(Fragment))) {
                 // ^ The spec only allows `<mx-reply>` at the very beginning
                 // and it's not supposed to be in the user input
                 const auto& rewrite = filterTag(tagName, attrs);
-                for (const auto& [tag, attrs]: rewrite) {
-                    tagsStack.top().push(tag);
-                    writer.writeStartElement(tag);
-                    writer.writeAttributes(attrs);
-                    if (tag == "a")
+                for (const auto& [rewrittenTag, rewrittenAttrs]: rewrite) {
+                    tagsStack.top().push(rewrittenTag);
+                    writer.writeStartElement(rewrittenTag);
+                    writer.writeAttributes(rewrittenAttrs);
+                    if (rewrittenTag == "a")
                         inAnchor = true;
                 }
             }
@@ -514,9 +544,10 @@ void Processor::runOn(const QString &html)
         case QXmlStreamReader::EndElement:
             if (tagsStack.empty()) {
                 const auto& tagName = reader.qualifiedName();
-                if (tagName != "body" && tagName != "html")
-                    qWarning() << "filterHtml(): empty tags stack, skipping"
-                               << ('/' + tagName);
+                if (tagName != u"body" && tagName != u"html")
+                    qCWarning(HTMLFILTER)
+                        << "filterHtml(): empty tags stack, skipping"
+                        << ('/' + tagName.toString());
                 break;
             }
             // Close as many elements as were opened in case StartElement
@@ -529,21 +560,28 @@ void Processor::runOn(const QString &html)
             break;
         case QXmlStreamReader::EndDocument:
             if (!tagsStack.empty())
-                qWarning().noquote().nospace()
-                    << __FUNCTION__ << ": Not all HTML tags closed";
+                qCWarning(HTMLFILTER).noquote().nospace()
+                    << ": Not all HTML tags closed";
+            if (mode == GenericToQt)
+                writer.writeEndDocument(); // </body></html>
             break;
         case QXmlStreamReader::NoToken:
             Q_ASSERT(reader.tokenType() != QXmlStreamReader::NoToken /*false*/);
             break;
-        case QXmlStreamReader::Invalid:
+        case QXmlStreamReader::Invalid: {
             errorPos = reader.characterOffset() - bodyOffset;
             errorString = reader.errorString();
-            qCritical().noquote() << "Invalid XHTML:" << html;
-            qCritical().nospace()
+            qCCritical(HTMLFILTER) << "Invalid XHTML:" << html;
+            qCCritical(HTMLFILTER).nospace()
                 << "Error at char " << errorPos << ": " << errorString;
-            qCritical().noquote()
-                << "Buffer at error:" << html.mid(reader.characterOffset());
+            const auto remainder =
+                QStringView(html).mid(reader.characterOffset());
+            qCCritical(HTMLFILTER).nospace()
+                << "Buffer at error: " << remainder << ", "
+                << html.size() - reader.characterOffset()
+                << " character(s) remaining";
             break;
+        }
         case QXmlStreamReader::Comment:
         case QXmlStreamReader::StartDocument:
         case QXmlStreamReader::DTD:
@@ -551,39 +589,40 @@ void Processor::runOn(const QString &html)
             continue; // All these should not affect firstElement state
         }
         // Unset first element once encountered non-whitespace under `<body>`
+        // NB: all `continue` statements above intentionally bypass this
         firstElement &= (bodyOffset <= 0 || reader.isWhitespace());
     }
 }
 
 template <size_t Len>
-inline QStringRef cssValue(const QStringRef& css,
-                           const char (&propertyNameWithColon)[Len])
+inline QStringView cssValue(QStringView css,
+                            const char16_t (&propertyNameWithColon)[Len])
 {
     return css.startsWith(propertyNameWithColon)
                ? css.mid(Len - 1).trimmed()
-               : QStringRef();
+               : QStringView();
 }
 
-Processor::rewrite_t Processor::filterTag(const QStringRef& tag,
+Processor::rewrite_t Processor::filterTag(QStringView tag,
                                           QXmlStreamAttributes attributes)
 {
     if (mode == MatrixToQt) {
-        if (tag == "del" || tag == "strike") { // Qt doesn't support these...
+        if (tag == u"del" || tag == u"strike") { // Qt doesn't support these...
             QXmlStreamAttributes attrs;
             attrs.append("style", "text-decoration:line-through");
             return { { "font", std::move(attrs) } };
         }
-        if (tag == "mx-reply")
+        if (tag == u"mx-reply")
             return { { "div", {} } }; // The spec says that mx-reply is HTML div
         // If `mx-reply` is encountered on the way to the wire, just pass it
     }
 
     rewrite_t rewrite { { tag.toString(), {} } };
-    if (tag == "code" && mode != GenericToQt) { // Special case
+    if (tag == u"code" && mode != GenericToQt) { // Special case
         copy_if(attributes.begin(), attributes.end(),
                 back_inserter(rewrite.back().second), [](const auto& a) {
-                    return a.qualifiedName() == "class"
-                           && a.value().startsWith("language-");
+                    return a.qualifiedName() == u"class"
+                           && a.value().startsWith(u"language-");
                 });
         return rewrite;
     }
@@ -600,8 +639,8 @@ Processor::rewrite_t Processor::filterTag(const QStringRef& tag,
     /// Find the first element in the rewrite that would accept color
     /// attributes (`font` and, only in Matrix HTML, `span`),
     /// and add the passed attribute to it
-    const auto& addColorAttr = [&rewrite, this](const QString& attrName,
-                                                const QStringRef& attrValue) {
+    const auto& addColorAttr = [&rewrite, this](QStringView attrName,
+                                                QStringView attrValue) {
         auto it = find_if(rewrite.begin(), rewrite.end(),
                           [this](const rewrite_t::value_type& element) {
                               return element.first == "font"
@@ -609,8 +648,8 @@ Processor::rewrite_t Processor::filterTag(const QStringRef& tag,
                                          && element.first == "span");
                           });
         if (it == rewrite.end())
-            it = rewrite.insert(rewrite.end(), { "font", {} });
-        it->second.append(attrName, attrValue.toString());
+            it = rewrite.insert(rewrite.end(), { QStringLiteral("font"), {} });
+        it->second.append(attrName.toString(), attrValue.toString());
     };
 
     const auto& passList = it->allowedAttrs;
@@ -621,12 +660,13 @@ Processor::rewrite_t Processor::filterTag(const QStringRef& tag,
         // is treated as possibly-Matrix
         if (mode != QtToMatrix) {
             if (aName == mxColorAttr) {
-                addColorAttr(htmlColorAttr, aValue);
+                addColorAttr(htmlColorAttr, aValue.toString());
                 continue;
             }
             if (aName == mxBgColorAttr) {
-                rewrite.front().second.append(htmlStyleAttr,
-                                              "background-color:" + aValue);
+                rewrite.front().second.append(QString::fromUtf16(htmlStyleAttr),
+                                              "background-color:"
+                                                  + aValue.toString());
                 continue;
             }
         } else {
@@ -638,30 +678,30 @@ Processor::rewrite_t Processor::filterTag(const QStringRef& tag,
                     p = p.trimmed();
                     if (p.isEmpty())
                         continue;
-                    if (const auto& v = cssValue(p, "color:"); !v.isEmpty()) {
+                    if (const auto& v = cssValue(p, u"color:"); !v.isEmpty()) {
                         addColorAttr(mxColorAttr, v);
-                    } else if (const auto& v = cssValue(p, "background-color:");
+                    } else if (const auto& v = cssValue(p, u"background-color:");
                                !v.isEmpty())
                         addColorAttr(mxBgColorAttr, v);
-                    else if (const auto& v = cssValue(p, "font-weight:");
-                             v == "bold" || v == "bolder" || v.toFloat() > 500)
+                    else if (const auto& v = cssValue(p, u"font-weight:");
+                             v == u"bold" || v == u"bolder" || v.toFloat() > 500)
                         rewrite.emplace_back().first = "b";
-                    else if (const auto& v = cssValue(p, "font-style:");
-                             v == "italic" || v.startsWith("oblique"))
+                    else if (const auto& v = cssValue(p, u"font-style:");
+                             v == u"italic" || v.startsWith(u"oblique"))
                         rewrite.emplace_back().first = "i";
-                    else if (const auto& v = cssValue(p, "text-decoration:");
-                             v.contains("line-through"))
-                        rewrite.emplace_back().first = "del";
+                    else if (const auto& v = cssValue(p, u"text-decoration:");
+                             v.contains(u"line-through"))
+                        rewrite.emplace_back().first = QStringLiteral("del");
                     else {
                         const auto& fontFamilies =
-                            cssValue(p, "font-family:").split(',');
+                            cssValue(p, u"font-family:").split(',');
                         for (auto ff: fontFamilies) {
                             ff = ff.trimmed();
                             if (ff.isEmpty())
                                 continue;
                             if (ff[0] == '\'' || ff[0] == '"')
-                                ff = ff.mid(1);
-                            if (ff.startsWith("monospace", Qt::CaseInsensitive)) {
+                                ff = ff.mid(1, ff.length() - 2);
+                            if (QFontDatabase().isFixedPitch(ff.toString())) {
                                 rewrite.emplace_back().first = "code";
                                 break;
                             }
@@ -676,16 +716,16 @@ Processor::rewrite_t Processor::filterTag(const QStringRef& tag,
 
         // Generic filtering for attributes
         if ((mode == GenericToQt
-             && (aName == htmlStyleAttr || aName == "class" || aName == "id"))
-            || (tag == "a" && aName == "href"
+             && (aName == htmlStyleAttr || aName == u"class" || aName == u"id"))
+            || (tag == u"a" && aName == u"href"
                 && any_of(begin(permittedSchemes), end(permittedSchemes),
-                          [&aValue](const char* s) {
+                          [&aValue](QStringView s) {
                               return aValue.startsWith(s);
                           }))
-            || (tag == "img" && aName == "src" && aValue.startsWith("mxc:"))
+            || (tag == u"img" && aName == u"src" && aValue.startsWith(u"mxc:"))
             || find(passList.begin(), passList.end(), a.qualifiedName())
                    != passList.end())
-            rewrite.front().second.push_back(move(a));
+            rewrite.front().second.push_back(std::move(a));
     } // for (a: attributes)
 
     // Remove the original <font> or <span> if they end up without attributes
@@ -703,7 +743,6 @@ void Processor::filterText(QString& text)
     if (text.isEmpty())
         return;
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
     if (options.testFlag(ConvertMarkdown)) {
         // Protect leading/trailing whitespaces (Markdown disregards them);
         // specific string doesn't matter as long as it isn't whitespace itself,
@@ -751,12 +790,10 @@ void Processor::filterText(QString& text)
             text.remove(text.indexOf(Marker), Marker.size());
         if (hasTrailingWhitespace)
             text.remove(text.lastIndexOf(Marker), Marker.size());
-    } else
-#endif
-    {
+    } else {
         text = text.toHtmlEscaped(); // The reader unescaped it
         Quotient::linkifyUrls(text);
-        text = "<body>" % text % "</body>";
+        text = "<span>" % text % "</span>";
     }
     // Re-process this piece of text as HTML but dump text snippets as they are,
     // without recursing into filterText() again
