@@ -1,27 +1,20 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2015 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2015 Felix Rohrbach <kde@fxrh.de>              *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
 #include "logindialog.h"
 
-#include <connection.h>
-#include <ssosession.h>
-#include <settings.h>
+#include "logging_categories.h"
+
+#include <Quotient/connection.h>
+#include <Quotient/accountregistry.h>
+#include <Quotient/qt_connection_util.h>
+#include <Quotient/ssosession.h>
+#include <Quotient/settings.h>
 
 #include <QtWidgets/QLineEdit>
 #include <QtWidgets/QPushButton>
@@ -36,13 +29,16 @@ using Quotient::Connection;
 static const auto MalformedServerUrl =
         LoginDialog::tr("The server URL doesn't look valid");
 
-LoginDialog::LoginDialog(const QString& statusMessage, QWidget* parent,
-                         const QStringList& knownAccounts)
+LoginDialog::LoginDialog(const QString& statusMessage,
+                         Quotient::AccountRegistry* loggedInAccounts,
+                         QWidget* parent, const QStringList& knownAccounts)
     : Dialog(tr("Login"), parent, Dialog::StatusLine, tr("Login"),
              Dialog::NoExtraButtons)
     , userEdit(new QLineEdit(this))
     , passwordEdit(new QLineEdit(this))
     , initialDeviceName(new QLineEdit(this))
+    , deviceId(new QLineEdit(this))
+    , enableEncryption(new QCheckBox(tr("Enable E2EE (BETA)"), this))
     , serverEdit(new QLineEdit(QStringLiteral("https://matrix.org"), this))
     , saveTokenCheck(new QCheckBox(tr("Stay logged in"), this))
     , m_connection(new Connection)
@@ -50,25 +46,41 @@ LoginDialog::LoginDialog(const QString& statusMessage, QWidget* parent,
     setup(statusMessage);
     setPendingApplyMessage(tr("Connecting and logging in, please wait"));
 
-    connect(userEdit, &QLineEdit::editingFinished, m_connection.data(), [=] {
-        auto userId = userEdit->text();
-        if (userId.startsWith('@') && userId.indexOf(':') != -1) {
-            setStatusMessage(tr("Resolving the homeserver..."));
-            serverEdit->clear();
-            button(QDialogButtonBox::Ok)->setEnabled(false);
-            m_connection->resolveServer(userId);
-        }
-    });
+    connect(userEdit, &QLineEdit::editingFinished, m_connection.get(),
+            [this, loggedInAccounts, knownAccounts] {
+                auto userId = userEdit->text();
+                if (!userId.startsWith('@') || !userId.contains(':'))
+                    return;
 
-    connect(serverEdit, &QLineEdit::editingFinished, m_connection.data(), [this] {
-        if (QUrl hsUrl { serverEdit->text() }; hsUrl.isValid()) {
-            m_connection->setHomeserver(serverEdit->text());
-            button(QDialogButtonBox::Ok)->setEnabled(true);
-        } else {
-            setStatusMessage(MalformedServerUrl);
-            button(QDialogButtonBox::Ok)->setEnabled(false);
-        }
-    });
+                button(QDialogButtonBox::Ok)->setEnabled(false);
+                if (loggedInAccounts->get(userId)) {
+                    setStatusMessage(
+                        tr("This account is logged in already"));
+                    return;
+                }
+                if (knownAccounts.contains(userId)) {
+                    Quotient::AccountSettings acct{ userId };
+                    initialDeviceName->setText(acct.deviceName());
+                    deviceId->setText(acct.deviceId());
+                } else {
+                    initialDeviceName->clear();
+                    deviceId->clear();
+                }
+                setStatusMessage(tr("Resolving the homeserver..."));
+                serverEdit->clear();
+                m_connection->resolveServer(userId);
+            });
+
+    connect(serverEdit, &QLineEdit::editingFinished, m_connection.get(),
+            [this, knownAccounts] {
+                if (QUrl hsUrl{ serverEdit->text() }; hsUrl.isValid()) {
+                    m_connection->setHomeserver(hsUrl);
+                    button(QDialogButtonBox::Ok)->setEnabled(true);
+                } else {
+                    setStatusMessage(MalformedServerUrl);
+                    button(QDialogButtonBox::Ok)->setEnabled(false);
+                }
+            });
 
     // This button is only shown when BOTH password auth and SSO are available
     // If only one flow is there, the "Login" button text is changed instead
@@ -76,7 +88,7 @@ LoginDialog::LoginDialog(const QString& statusMessage, QWidget* parent,
                                              QDialogButtonBox::AcceptRole);
     connect(ssoButton, &QPushButton::clicked, this, &LoginDialog::loginWithSso);
     ssoButton->setHidden(true);
-    connect(m_connection.data(), &Connection::loginFlowsChanged, this,
+    connect(m_connection.get(), &Connection::loginFlowsChanged, this,
             [this, ssoButton] {
                 // There may be more ways to login but Quaternion only supports
                 // SSO and password for now; in the worst case of no known
@@ -103,31 +115,40 @@ LoginDialog::LoginDialog(const QString& statusMessage, QWidget* parent,
                 m_connection->setHomeserver(homeserver);
 
             initialDeviceName->setText(account.deviceName());
+            deviceId->setText(account.deviceId());
+            enableEncryption->setChecked(account.get<bool>(E2eeEnabledSetting));
             saveTokenCheck->setChecked(account.keepLoggedIn());
             passwordEdit->setFocus();
         }
         else
         {
+            enableEncryption->setChecked(false);
             saveTokenCheck->setChecked(false);
             userEdit->setFocus();
         }
     }
 }
 
-LoginDialog::LoginDialog(const QString &statusMessage, QWidget* parent,
-                         const Quotient::AccountSettings& reloginData)
+LoginDialog::LoginDialog(const QString& statusMessage,
+                         const Quotient::AccountSettings& reloginAccount,
+                         QWidget* parent)
     : Dialog(tr("Re-login"), parent, Dialog::StatusLine, tr("Re-login"),
              Dialog::NoExtraButtons)
-    , userEdit(new QLineEdit(reloginData.userId(), this))
+    , userEdit(new QLineEdit(reloginAccount.userId(), this))
     , passwordEdit(new QLineEdit(this))
-    , initialDeviceName(new QLineEdit(reloginData.deviceName(), this))
-    , serverEdit(new QLineEdit(reloginData.homeserver().toString(), this))
+    , initialDeviceName(new QLineEdit(reloginAccount.deviceName(), this))
+    , deviceId(new QLineEdit(reloginAccount.deviceId(), this))
+    , enableEncryption(new QCheckBox(tr("Enable E2EE (BETA)"), this))
+    , serverEdit(new QLineEdit(reloginAccount.homeserver().toString(), this))
     , saveTokenCheck(new QCheckBox(tr("Stay logged in"), this))
     , m_connection(new Connection)
 {
     setup(statusMessage);
     userEdit->setReadOnly(true);
     userEdit->setFrame(false);
+    initialDeviceName->setReadOnly(true);
+    initialDeviceName->setFrame(false);
+    enableEncryption->setChecked(reloginAccount.get<bool>(E2eeEnabledSetting));
     setPendingApplyMessage(tr("Restoring access, please wait"));
 }
 
@@ -137,7 +158,7 @@ void LoginDialog::setup(const QString& statusMessage)
     passwordEdit->setEchoMode( QLineEdit::Password );
 
     // This is triggered whenever the server URL has been changed
-    connect(m_connection.data(), &Connection::homeserverChanged, serverEdit,
+    connect(m_connection.get(), &Connection::homeserverChanged, serverEdit,
             [this](const QUrl& hsUrl) {
         serverEdit->setText(hsUrl.toString());
         if (hsUrl.isValid())
@@ -147,7 +168,7 @@ void LoginDialog::setup(const QString& statusMessage)
         // do LoginDialog::loginWithBestFlow() as soon as flows arrive
         button(QDialogButtonBox::Ok)->setEnabled(hsUrl.isValid());
     });
-    connect(m_connection.data(), &Connection::loginFlowsChanged, this, [this] {
+    connect(m_connection.get(), &Connection::loginFlowsChanged, this, [this] {
         serverEdit->setText(m_connection->homeserver().toString());
         setStatusMessage(m_connection->isUsable()
                              ? tr("The homeserver is available")
@@ -156,29 +177,39 @@ void LoginDialog::setup(const QString& statusMessage)
     });
     // This overrides the above in case of an unsuccessful attempt to resolve
     // the server URL from a changed MXID
-    connect(m_connection.data(), &Connection::resolveError, this,
+    connect(m_connection.get(), &Connection::resolveError, this,
             [this](const QString& message) {
-                qDebug() << "Resolve error";
+                qCDebug(MAIN) << "Failed to resolve the homeserver:" << message;
                 serverEdit->clear();
                 setStatusMessage(message);
             });
-    connect(m_connection.data(), &Connection::connected,
+    deviceId->setReadOnly(true);
+    deviceId->setFrame(false);
+    deviceId->setPlaceholderText(tr(
+        "(none)", "The device id label text when there's no saved device id"));
+    connect(initialDeviceName, &QLineEdit::textChanged, deviceId,
+            &QLineEdit::clear);
+
+    m_connection->enableEncryption(enableEncryption->isChecked());
+    connect(enableEncryption, &QCheckBox::stateChanged, m_connection.get(),
+            &Connection::enableEncryption);
+    connect(m_connection.get(), &Connection::connected,
             this, &Dialog::accept);
-    connect(m_connection.data(), &Connection::loginError,
+    connect(m_connection.get(), &Connection::loginError,
             this, &Dialog::applyFailed);
     auto* formLayout = addLayout<QFormLayout>();
     formLayout->addRow(tr("Matrix ID"), userEdit);
     formLayout->addRow(tr("Password"), passwordEdit);
     formLayout->addRow(tr("Device name"), initialDeviceName);
+    formLayout->addRow(tr("Saved device id"), deviceId);
     formLayout->addRow(tr("Connect to server"), serverEdit);
+    formLayout->addRow(enableEncryption);
     formLayout->addRow(saveTokenCheck);
 }
 
-LoginDialog::~LoginDialog() = default;
-
 Connection* LoginDialog::releaseConnection()
 {
-    return m_connection.take();
+    return m_connection.release();
 }
 
 QString LoginDialog::deviceName() const
@@ -206,9 +237,9 @@ void LoginDialog::apply()
         m_connection->setHomeserver(url);
 
         // Wait for new flows and check them
-        connectSingleShot(m_connection.data(), &Connection::loginFlowsChanged,
+        connectSingleShot(m_connection.get(), &Connection::loginFlowsChanged,
                           this, [this] {
-                              qDebug()
+                              qCDebug(MAIN)
                                   << "Received login flows, trying to login";
                               loginWithBestFlow();
                           });
@@ -229,12 +260,13 @@ void LoginDialog::loginWithBestFlow()
 void LoginDialog::loginWithPassword()
 {
     m_connection->loginWithPassword(userEdit->text(), passwordEdit->text(),
-                                  initialDeviceName->text());
+                                    initialDeviceName->text(), deviceId->text());
 }
 
 void LoginDialog::loginWithSso()
 {
-    auto* ssoSession = m_connection->prepareForSso(initialDeviceName->text());
+    auto* ssoSession = m_connection->prepareForSso(initialDeviceName->text(),
+                                                   deviceId->text());
     if (!QDesktopServices::openUrl(ssoSession->ssoUrl())) {
         auto* instructionsBox =
             new Dialog(tr("Single sign-on"), QDialogButtonBox::NoButton, this);
