@@ -1,60 +1,54 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2015 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2015 Felix Rohrbach <kde@fxrh.de>                        *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
 #include "messageeventmodel.h"
 
 #include <QtCore/QDebug>
+#include <QtGui/QPalette>
 #include <QtQml> // for qmlRegisterType()
 
 #include "../quaternionroom.h"
 #include "../htmlfilter.h"
-#include <connection.h>
-#include <user.h>
-#include <settings.h>
-#include <events/encryptionevent.h>
-#include <events/roommemberevent.h>
-#include <events/simplestateevents.h>
-#include <events/redactionevent.h>
-#include <events/roomavatarevent.h>
-#include <events/roomcreateevent.h>
-#include <events/roomtombstoneevent.h>
-#include <events/roomcanonicalaliasevent.h>
-#include <events/reactionevent.h>
+#include "../logging_categories.h"
+
+#include <Quotient/connection.h>
+#include <Quotient/user.h>
+#include <Quotient/settings.h>
+#include <Quotient/events/encryptionevent.h>
+#include <Quotient/events/roommemberevent.h>
+#include <Quotient/events/simplestateevents.h>
+#include <Quotient/events/redactionevent.h>
+#include <Quotient/events/roomavatarevent.h>
+#include <Quotient/events/roomcreateevent.h>
+#include <Quotient/events/roomtombstoneevent.h>
+#include <Quotient/events/roomcanonicalaliasevent.h>
+#include <Quotient/events/reactionevent.h>
 
 QHash<int, QByteArray> MessageEventModel::roleNames() const
 {
     static const auto roles = [this] {
         auto roles = QAbstractItemModel::roleNames();
+        // Not every Qt standard role has a role name, turns out
+        roles.insert(Qt::ForegroundRole, "foreground");
         roles.insert(EventTypeRole, "eventType");
         roles.insert(EventIdRole, "eventId");
-        roles.insert(TimeRole, "time");
-        roles.insert(SectionRole, "section");
-        roles.insert(AboveSectionRole, "aboveSection");
+        roles.insert(DateTimeRole, "dateTime");
+        roles.insert(DateRole, "date");
+        roles.insert(EventGroupingRole, "eventGrouping");
         roles.insert(AuthorRole, "author");
-        roles.insert(AboveAuthorRole, "aboveAuthor");
+        roles.insert(AuthorHasAvatarRole, "authorHasAvatar");
         roles.insert(ContentRole, "content");
         roles.insert(ContentTypeRole, "contentType");
         roles.insert(HighlightRole, "highlight");
         roles.insert(SpecialMarksRole, "marks");
         roles.insert(LongOperationRole, "progressInfo");
         roles.insert(AnnotationRole, "annotation");
-        roles.insert(EventResolvedTypeRole, "eventResolvedType");
+        roles.insert(EventClassNameRole, "eventClassName");
         roles.insert(RefRole, "refId");
         roles.insert(ReactionsRole, "reactions");
         return roles;
@@ -66,19 +60,21 @@ MessageEventModel::MessageEventModel(QObject* parent)
     : QAbstractListModel(parent)
 {
     using namespace Quotient;
-#if (QT_VERSION >= QT_VERSION_CHECK(5, 14, 0))
     qmlRegisterAnonymousType<FileTransferInfo>("Quotient", 1);
-#else
-    qmlRegisterType<FileTransferInfo>(); qRegisterMetaType<FileTransferInfo>();
-#endif
-    qmlRegisterUncreatableType<EventStatus>("Quotient", 1, 0, "EventStatus",
-        "EventStatus is not a creatable type");
+    qmlRegisterUncreatableMetaObject(EventStatus::staticMetaObject,
+                                     "Quotient", 1, 0, "EventStatus",
+                                     "Access to EventStatus enums only");
+    qmlRegisterUncreatableMetaObject(EventGrouping::staticMetaObject,
+                                     "Quotient", 1, 0, "EventGrouping",
+                                     "Access to enums only");
     // This could be a single line in changeRoom() but then there's a race
     // condition between the model reset completion and the room property
     // update in QML - connecting the two signals early on overtakes any QML
     // connection to modelReset. Ideally the room property could use modelReset
     // for its NOTIFY signal - unfortunately, moc doesn't support using
     // parent's signals with parameters in NOTIFY
+    // NB: this makes all roomChanged connections order before modelReset
+    // connections
     connect(this, &MessageEventModel::modelReset, //
             this, &MessageEventModel::roomChanged);
 }
@@ -90,13 +86,18 @@ void MessageEventModel::changeRoom(QuaternionRoom* room)
     if (room == m_currentRoom)
         return;
 
-    if (m_currentRoom)
-        qDebug() << "Disconnecting event model from"
-                 << m_currentRoom->objectName();
-    beginResetModel();
-    if (m_currentRoom)
+    if (m_currentRoom) {
+        qCDebug(EVENTMODEL)
+            << "Disconnecting event model from" << m_currentRoom->objectName();
+        // Reset the model to a null room first to make sure QML dismantles
+        // last room's objects before the room is actually changed
+        beginResetModel();
         m_currentRoom->disconnect(this);
+        m_currentRoom = nullptr;
+        endResetModel();
+    }
 
+    beginResetModel();
     m_currentRoom = room;
     if (m_currentRoom) {
         using namespace Quotient;
@@ -111,13 +112,15 @@ void MessageEventModel::changeRoom(QuaternionRoom* room)
         connect(m_currentRoom, &Room::addedMessages, this,
                 [this] (int lowest, int biggest) {
                     endInsertRows();
-                    if (biggest < m_currentRoom->maxTimelineIndex())
-                    {
+                    if (biggest < m_currentRoom->maxTimelineIndex()) {
+                        // When historical events arrive, make sure to update
+                        // the previously-oldest event (e.g. to move author mark
+                        // to an older event)
                         const auto rowBelowInserted =
                             m_currentRoom->maxTimelineIndex() - biggest
                             + timelineBaseIndex() - 1;
                         refreshEventRoles(rowBelowInserted,
-                                         {AboveAuthorRole, AboveSectionRole});
+                                          { EventGroupingRole });
                     }
                     for (auto i = m_currentRoom->maxTimelineIndex() - biggest;
                               i <= m_currentRoom->maxTimelineIndex() - lowest;
@@ -152,7 +155,7 @@ void MessageEventModel::changeRoom(QuaternionRoom* room)
                     refreshLastUserEvents(0);
                     if (timelineBaseIndex() > 0) // Refresh below, see #312
                         refreshEventRoles(timelineBaseIndex() - 1,
-                                          {AboveAuthorRole, AboveSectionRole});
+                                          { EventGroupingRole });
                 });
         connect(m_currentRoom, &Room::pendingEventChanged,
                 this, &MessageEventModel::refreshRow);
@@ -160,7 +163,7 @@ void MessageEventModel::changeRoom(QuaternionRoom* room)
                 this, [this] (int i) { beginRemoveRows({}, i, i); });
         connect(m_currentRoom, &Room::pendingEventDiscarded,
                 this, &MessageEventModel::endRemoveRows);
-        connect(m_currentRoom, &Room::readMarkerMoved,
+        connect(m_currentRoom, &Room::fullyReadMarkerMoved,
                 this, &MessageEventModel::readMarkerUpdated);
         connect(m_currentRoom, &Room::replacedEvent, this,
                 [this] (const RoomEvent* newEvent) {
@@ -175,10 +178,12 @@ void MessageEventModel::changeRoom(QuaternionRoom* room)
                 this, &MessageEventModel::refreshEvent);
         connect(m_currentRoom, &Room::fileTransferFailed,
                 this, &MessageEventModel::refreshEvent);
-        connect(m_currentRoom, &Room::fileTransferCancelled,
-                this, &MessageEventModel::refreshEvent);
-        qDebug() << "Event model connected to room" << room->objectName()
-                 << "as" << room->localUser()->id();
+        qCDebug(EVENTMODEL)
+            << "Event model connected to room" << room->objectName() //
+            << "as" << room->localUser()->id();
+        // If the timeline isn't loaded, ask for at least something right away
+        if (room->timelineSize() == 0)
+            room->getHistory(30);
     }
     endResetModel();
     emit readMarkerUpdated();
@@ -190,7 +195,8 @@ int MessageEventModel::refreshEvent(const QString& eventId)
     if (row >= 0)
         refreshEventRoles(row);
     else
-        qWarning() << "Trying to refresh inexistent event:" << eventId;
+        qCWarning(EVENTMODEL)
+            << "Trying to refresh inexistent event:" << eventId;
     return row;
 }
 
@@ -209,7 +215,7 @@ int MessageEventModel::readMarkerVisualIndex() const
 {
     if (!m_currentRoom)
         return -1; // Beyond the bottommost (sync) edge of the timeline
-    if (auto r = findRow(m_currentRoom->readMarkerEventId()); r != -1) {
+    if (auto r = findRow(m_currentRoom->lastFullyReadEventId()); r != -1) {
         // Ensure that the read marker is on a visible event
         // TODO: move this to libQuotient once it allows to customise
         //       event status calculation
@@ -274,13 +280,13 @@ QDateTime MessageEventModel::makeMessageTimestamp(
         return { it->event()->originTimestamp().date(), {0,0}, Qt::LocalTime };
 
     // What kind of room is that?..
-    qCritical() << "No valid timestamps in the room timeline!";
+    qCCritical(EVENTMODEL) << "No valid timestamps in the room timeline!";
     return {};
 }
 
 QString MessageEventModel::renderDate(const QDateTime& timestamp)
 {
-    auto date = timestamp.toLocalTime().date();
+    auto date = timestamp.date();
     static Quotient::SettingsGroup sg { "UI" };
     if (sg.get("use_human_friendly_dates",
                sg.get("banner_human_friendly_date", true)))
@@ -370,7 +376,7 @@ bool MessageEventModel::isUserActivityNotable(
         {
             if (e.stateKey() != userId)
                 return true; // An action on another member is notable
-            if (!me->isLeave() && me->membership() != MembershipType::Ban)
+            if (!me->isLeave() && me->membership() != Membership::Ban)
                 continue;
 
             leaveFound = true;
@@ -414,6 +420,29 @@ int MessageEventModel::rowCount(const QModelIndex& parent) const
     return m_currentRoom->timelineSize() + m_currentRoom->pendingEvents().size();
 }
 
+inline QColor mixColors(QColor base, QColor tint, qreal mixRatio = 0.5)
+{
+    mixRatio = tint.alphaF() * mixRatio;
+    const auto baseRatio = 1 - mixRatio;
+    return QColor::fromRgbF(tint.redF() * mixRatio + base.redF() * baseRatio,
+                            tint.greenF() * mixRatio + base.greenF() * baseRatio,
+                            tint.blueF() * mixRatio + base.blueF() * baseRatio,
+                            mixRatio + base.alphaF() * baseRatio);
+}
+
+inline QColor fadedTextColor(QColor unfadedColor, qreal fadeRatio = 0.5)
+{
+    return mixColors(QPalette().color(QPalette::Disabled, QPalette::Text),
+                     unfadedColor, fadeRatio);
+}
+
+QColor MessageEventModel::fadedBackColor(QColor unfadedColor,
+                                         qreal fadeRatio) const
+{
+    return mixColors(QPalette().color(QPalette::Disabled, QPalette::Base),
+                     unfadedColor, fadeRatio);
+}
+
 QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
 {
     const auto row = idx.row();
@@ -429,10 +458,9 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
     const auto& evt = isPending ? **pendingIt : **timelineIt;
 
     using namespace Quotient;
-    if( role == Qt::DisplayRole )
-    {
-        if (evt.isRedacted())
-        {
+    static Settings settings;
+    if (role == Qt::DisplayRole) {
+        if (evt.isRedacted()) {
             auto reason = evt.redactedBecause()->reason();
             if (reason.isEmpty())
                 return tr("Redacted");
@@ -441,7 +469,7 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
         }
 
         // clang-format off
-        return visit(evt
+        return switchOnType(evt
             , [this] (const RoomMessageEvent& e) {
                 // clang-format on
                 using namespace MessageEventContent;
@@ -456,9 +484,8 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                     // to returning the prettified plain text
                     if (errorPos != -1) {
                         cleanHtml = m_currentRoom->prettyPrint(e.plainBody());
-                        static Settings settings;
                         // A manhole to visualise HTML errors
-                        if (settings.get("Debug/html", false))
+                        if (settings.get<bool>("Debug/html"))
                             cleanHtml +=
                                 QStringLiteral("<br /><font color=\"red\">"
                                                "At pos %1: %2</font>")
@@ -484,11 +511,11 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                 // The below code assumes senderName output in AuthorRole
                 switch( e.membership() )
                 {
-                    case MembershipType::Invite:
-                    case MembershipType::Join: {
+                    case Membership::Invite:
+                    case Membership::Join: {
                         QString text {};
                         // Part 1: invites and joins
-                        if (e.membership() == MembershipType::Invite)
+                        if (e.membership() == Membership::Invite)
                             text = tr("invited %1 to the room")
                                    .arg(subjectName);
                         else if (e.changesMembership())
@@ -506,29 +533,31 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
 
                         // Part 2: profile changes of joined members
                         if (e.isRename()
-                            && Settings().get("UI/show_rename", true)) {
-                            if (e.displayName().isEmpty())
+                            && settings.get("UI/show_rename", true)) {
+                            const auto& newDisplayName =
+                                e.newDisplayName().value_or(QString());
+                            if (newDisplayName.isEmpty())
                                 text = tr("cleared the display name");
                             else
                                 text = tr("changed the display name to %1")
-                                       .arg(e.displayName().toHtmlEscaped());
+                                           .arg(newDisplayName.toHtmlEscaped());
                         }
                         if (e.isAvatarUpdate()
-                            && Settings().get("UI/show_avatar_update", true)) {
+                            && settings.get("UI/show_avatar_update", true)) {
                             if (!text.isEmpty())
                                 //: Joiner for member profile updates;
                                 //: mind the leading and trailing spaces!
                                 text += tr(" and ");
-                            if (e.avatarUrl().isEmpty())
-                                text += tr("cleared the avatar");
-                            else
-                                text += tr("updated the avatar");
+                            text += !e.newAvatarUrl()
+                                            || e.newAvatarUrl()->isEmpty()
+                                        ? tr("cleared the avatar")
+                                        : tr("updated the avatar");
                         }
                         return text;
                     }
-                    case MembershipType::Leave:
+                    case Membership::Leave:
                         if (e.prevContent() &&
-                            e.prevContent()->membership == MembershipType::Invite)
+                            e.prevContent()->membership == Membership::Invite)
                         {
                             return (e.senderId() != e.userId())
                                     ? tr("withdrew %1's invitation").arg(subjectName)
@@ -536,7 +565,7 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                         }
 
                         if (e.prevContent() &&
-                                e.prevContent()->membership == MembershipType::Ban)
+                                e.prevContent()->membership == Membership::Ban)
                         {
                             return (e.senderId() != e.userId())
                                     ? tr("unbanned %1").arg(subjectName)
@@ -550,7 +579,7 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                                     .arg(subjectName,
                                          e.reason().toHtmlEscaped())
                                 : tr("left the room");
-                    case MembershipType::Ban:
+                    case Membership::Ban:
                         return (e.senderId() != e.userId())
                                 ? e.reason().isEmpty()
                                   ? tr("banned %1 from the room")
@@ -559,7 +588,7 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                                     .arg(subjectName,
                                          e.reason().toHtmlEscaped())
                                 : tr("self-banned from the room");
-                    case MembershipType::Knock:
+                    case Membership::Knock:
                         return tr("knocked");
                     default:
                         ;
@@ -567,11 +596,6 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                 return tr("made something unknown");
                 // clang-format off
             }
-            , [] (const RoomAliasesEvent& e) {
-                return tr("has set room aliases on server %1 to: %2")
-                       .arg(e.stateKey(),
-                            QLocale().createSeparatedList(e.aliases()));
-            }
             , [] (const RoomCanonicalAliasEvent& e) {
                 return (e.alias().isEmpty())
                         ? tr("cleared the room main alias")
@@ -606,7 +630,7 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                 return tr("upgraded the room: %1")
                        .arg(e.serverMessage().toHtmlEscaped());
             }
-            , [] (const StateEventBase& e) {
+            , [] (const StateEvent& e) {
                 // A small hack for state events from TWIM bot
                 return e.stateKey() == "twim"
                     ? tr("updated the database", "TWIM bot updated the database")
@@ -622,9 +646,45 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
         // clang-format on
     }
 
+    if (role == Qt::ForegroundRole) {
+        using CG = QPalette::ColorGroup;
+        using CR = QPalette::ColorRole;
+
+        if (evt.isRedacted())
+            return QPalette().color(CG::Disabled, CR::Text);
+
+        auto normalTextColor = QPalette().color(CG::Active, CR::Text);
+        if (isPending) {
+            using ES = Quotient::EventStatus::Code;
+            switch (pendingIt->deliveryStatus()) {
+            case ES::Submitted:
+            case ES::SendingFailed:
+            case ES::Departed:
+                return fadedTextColor(normalTextColor);
+            default:;
+            }
+        }
+        // Background highlighting mode is handled entirely in QML
+        if (m_currentRoom->isEventHighlighted(&evt)
+            && settings.get<QString>(QStringLiteral("UI/highlight_mode"))
+                   == "text")
+            return settings.get(QStringLiteral("UI/highlight_color"),
+                                QStringLiteral("orange"));
+
+        if (isPending || evt.senderId() == m_currentRoom->localUser()->id())
+            normalTextColor = mixColors(normalTextColor,
+                            settings.get(QStringLiteral("UI/outgoing_color"),
+                                         QStringLiteral("#4A8780")), 0.5);
+
+        const auto* const rme = eventCast<const RoomMessageEvent>(&evt);
+        return rme && rme->msgtype() != MessageEventType::Notice
+                   ? normalTextColor
+                   : fadedTextColor(normalTextColor);
+    }
+
     if( role == Qt::ToolTipRole )
     {
-        return evt.originalJson();
+        return QJsonDocument(evt.fullJson()).toJson();
     }
 
     if( role == EventTypeRole )
@@ -649,8 +709,8 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
         return "other";
     }
 
-    if (role == EventResolvedTypeRole)
-        return EventTypeRegistry::getMatrixType(evt.type());
+    if (role == EventClassNameRole)
+        return evt.metaType().className;
 
     if( role == AuthorRole )
     {
@@ -660,6 +720,10 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
                                    : m_currentRoom->user(evt.senderId()));
     }
 
+    if (role == AuthorHasAvatarRole) {
+        return m_currentRoom->memberAvatarUrl(evt.senderId()).isValid();
+    }
+
     if (role == ContentTypeRole)
     {
         if (auto e = eventCast<const RoomMessageEvent>(&evt))
@@ -701,72 +765,75 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
             return EventStatus::Hidden; // Never show, even pending
 
         if (isPending)
-            return !Settings().get<bool>("UI/suppress_local_echo")
+            return !settings.get<bool>("UI/suppress_local_echo")
                     ? pendingIt->deliveryStatus() : EventStatus::Hidden;
 
         // isReplacement?
-        if (auto e = eventCast<const RoomMessageEvent>(&evt))
+        if (auto e = eventCast<const RoomMessageEvent>(&evt)) {
             if (!e->replacedEvent().isEmpty())
                 return EventStatus::Hidden;
+            if (e->isReplaced()) {
+                return EventStatus::Replaced;
+            }
+        }
 
-        if ((is<RoomAliasesEvent>(evt) || is<RoomCanonicalAliasEvent>(evt))
-                && !Settings().value("UI/show_alias_update", true).toBool())
+        if (is<RoomCanonicalAliasEvent>(evt)
+            && !settings.get<bool>("UI/show_alias_update", true))
             return EventStatus::Hidden;
 
         auto* memberEvent = timelineIt->viewAs<RoomMemberEvent>();
-        if (memberEvent)
-        {
-            if ((memberEvent->isJoin() || memberEvent->isLeave()) &&
-                    !Settings().value("UI/show_joinleave", true).toBool())
+        if (memberEvent) {
+            if ((memberEvent->isJoin() || memberEvent->isLeave())
+                && !settings.get<bool>("UI/show_joinleave", true))
                 return EventStatus::Hidden;
 
             if ((memberEvent->isInvite() || memberEvent->isRejectedInvite())
-                    && !Settings().value("UI/show_invite", true).toBool())
+                && !settings.get<bool>("UI/show_invite", true))
                 return EventStatus::Hidden;
 
             if ((memberEvent->isBan() || memberEvent->isUnban())
-                    && !Settings().value("UI/show_ban", true).toBool())
+                && !settings.get<bool>("UI/show_ban", true))
                 return EventStatus::Hidden;
 
-            bool hideRename = memberEvent->isRename()
+            bool hideRename =
+                memberEvent->isRename()
                 && (!memberEvent->isJoin() && !memberEvent->isLeave())
-                && !Settings().value("UI/show_rename", true).toBool();
-            bool hideAvatarUpdate = memberEvent->isAvatarUpdate()
-                && !Settings().value("UI/show_avatar_update", true).toBool();
+                && !settings.get<bool>("UI/show_rename", true);
+            bool hideAvatarUpdate =
+                memberEvent->isAvatarUpdate()
+                && !settings.get<bool>("UI/show_avatar_update", true);
             if ((hideRename && hideAvatarUpdate)
                     || (hideRename && !memberEvent->isAvatarUpdate())
                     || (hideAvatarUpdate && !memberEvent->isRename())) {
                 return EventStatus::Hidden;
             }
         }
-        if (memberEvent || evt.isRedacted())
-        {
-            if (evt.senderId() != m_currentRoom->localUser()->id() &&
-                    evt.stateKey() != m_currentRoom->localUser()->id() &&
-                    !Settings().value("UI/show_spammy").toBool())
-            {
-    //            QElapsedTimer et; et.start();
+        if (memberEvent || evt.isRedacted()) {
+            if (evt.senderId() != m_currentRoom->localUser()->id()
+                && evt.stateKey() != m_currentRoom->localUser()->id()
+                && !settings.get<bool>("UI/show_spammy")) {
+//                QElapsedTimer et; et.start();
                 auto hide = !isUserActivityNotable(timelineIt);
-    //            qDebug() << "Checked user activity for" << evt.id() << "in" << et;
+//                qCDebug(EVENTMODEL)
+//                    << "Checked user activity for" << evt.id() << "in" << et;
                 if (hide)
                     return EventStatus::Hidden;
             }
         }
 
         if (evt.isRedacted())
-            return Settings().value("UI/show_redacted").toBool()
+            return settings.get<bool>("UI/show_redacted")
                     ? EventStatus::Redacted : EventStatus::Hidden;
 
-        if (evt.isStateEvent() &&
-                static_cast<const StateEventBase&>(evt).repeatsState() &&
-                !Settings().value("UI/show_noop_events").toBool())
+        if (auto* stateEvt = eventCast<const StateEvent>(&evt);
+            stateEvt && stateEvt->repeatsState()
+            && !settings.get<bool>("UI/show_noop_events"))
             return EventStatus::Hidden;
 
         if (!evt.isStateEvent() && !is<RoomMessageEvent>(evt)
-                && !Settings().value("UI/show_unknown_events").toBool())
+            && !settings.get<bool>("UI/show_unknown_events"))
             return EventStatus::Hidden;
-
-        return evt.isReplaced() ? EventStatus::Replaced : EventStatus::Normal;
+        return EventStatus::Normal;
     }
 
     if( role == EventIdRole )
@@ -794,15 +861,15 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
         std::vector<Reaction> reactions; // using vector to maintain the order
         // XXX: Should the list be ordered by the number of reactions instead?
         const auto& annotations =
-            m_currentRoom->relatedEvents(evt, EventRelation::Annotation());
+            m_currentRoom->relatedEvents(evt, EventRelation::AnnotationType);
         for (const auto& a: annotations)
             if (const auto e = eventCast<const ReactionEvent>(a)) {
                 auto rIt = std::find_if(reactions.begin(), reactions.end(),
                                         [&e] (const Reaction& r) {
-                                            return r.key == e->relation().key;
+                                            return r.key == e->key();
                                        });
                 if (rIt == reactions.end())
-                    rIt = reactions.insert(reactions.end(), {e->relation().key});
+                    rIt = reactions.insert(reactions.end(), { e->key() });
 
                 rIt->authorsList << m_currentRoom->safeMemberName(e->senderId());
                 rIt->includesLocalUser |=
@@ -832,24 +899,29 @@ QVariant MessageEventModel::data(const QModelIndex& idx, int role) const
         return qmlReactions;
     }
 
-    if( role == TimeRole || role == SectionRole)
+    if( role == DateTimeRole || role == DateRole)
     {
-        auto ts = isPending ? pendingIt->lastUpdated()
-                            : makeMessageTimestamp(timelineIt);
-        return role == TimeRole ? QVariant(ts) : renderDate(ts);
+        auto ts = (isPending ? pendingIt->lastUpdated()
+                             : makeMessageTimestamp(timelineIt)).toLocalTime();
+        return role == DateTimeRole ? QVariant(ts) : renderDate(ts);
     }
 
-    if( role == AboveSectionRole || role == AboveAuthorRole)
+    if (role == EventGroupingRole) {
         for (auto r = row + 1; r < rowCount(); ++r)
         {
             auto i = index(r);
             if (data(i, SpecialMarksRole) != EventStatus::Hidden)
-                return data(i, role == AboveSectionRole
-                                ? SectionRole : AuthorRole);
+                return data(i, DateRole) != data(idx, DateRole)
+                           ? EventGrouping::ShowDateAndAuthor
+                       : data(i, AuthorRole) != data(idx, AuthorRole)
+                           ? EventGrouping::ShowAuthor
+                           : EventGrouping::KeepPreviousGroup;
         }
+        return EventGrouping::ShowDateAndAuthor; // No events before
+    }
 
     if (role == RefRole)
-        return visit(
+        return switchOnType(
             evt, [](const RoomCreateEvent& e) { return e.predecessor().roomId; },
             [](const RoomTombstoneEvent& e) { return e.successorRoomId(); });
 
