@@ -1,29 +1,20 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2016 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2016 Felix Rohrbach <kde@fxrh.de>                        *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
 #include "roomlistmodel.h"
 
 #include "../quaternionroom.h"
+#include "../logging_categories.h"
 
-#include <user.h>
-#include <connection.h>
-#include <settings.h>
+#include <Quotient/eventstats.h>
+#include <Quotient/user.h>
+#include <Quotient/connection.h>
+#include <Quotient/settings.h>
 
 // See a comment in the same place at userlistmodel.cpp
 #include <QtWidgets/QAbstractItemView>
@@ -48,12 +39,11 @@ void RoomListModel::addConnection(Quotient::Connection* connection)
 
     using namespace Quotient;
     m_connections.emplace_back(connection, this);
-    connect(connection, &Connection::loggedOut, this,
-            [=] { deleteConnection(connection); });
     connect(connection, &Connection::newRoom, this, &RoomListModel::addRoom);
     m_roomOrder->connectSignals(connection);
 
-    for (auto* r: connection->allRooms())
+    const auto& allRooms = connection->allRooms();
+    for (auto* r: allRooms)
         addRoom(r);
 }
 
@@ -82,13 +72,15 @@ void RoomListModel::deleteTag(QModelIndex index)
     const auto tag = m_roomGroups[index.row()].key.toString();
     if (tag.isEmpty())
     {
-        qCritical() << "RoomListModel: Invalid tag at position" << index.row();
+        qCCritical(MODELS) << "RoomListModel: Invalid tag at position"
+                           << index.row();
         return;
     }
     if (tag.startsWith(RoomGroup::SystemPrefix))
     {
-        qWarning() << "RoomListModel: System groups cannot be deleted "
-                      "(tried to delete" << tag << "group)";
+        qCWarning(MODELS) << "RoomListModel: System groups cannot be deleted "
+                             "(tried to delete"
+                          << tag << "group)";
         return;
     }
     // After the below loop, the respective group will magically disappear from
@@ -111,8 +103,9 @@ void RoomListModel::visitRoom(const Room& room,
         if (roomAt(idx) == &room)
             visitor(idx);
         else {
-            qCritical() << "Room at" << idx << "is" << roomAt(idx)->objectName()
-                        << "instead of" << room.objectName();
+            qCCritical(MODELS)
+                << "Room at" << idx << "is" << roomAt(idx)->objectName()
+                << "instead of" << room.objectName();
             Q_ASSERT(false);
         }
     }
@@ -217,18 +210,19 @@ void RoomListModel::addRoomToGroups(Room* room, QVariantList groups)
         const auto rIt = lowerBoundRoom(*gIt, room);
         if (rIt != gIt->rooms.cend() && *rIt == room)
         {
-            qWarning() << "RoomListModel:" << room->objectName()
-                       << "is already listed under group" << g.toString();
+            qCWarning(MODELS)
+                << "RoomListModel:" << room->objectName()
+                << "is already listed under group" << g.toString();
             continue;
         }
-        const auto rPos = int(rIt - gIt->rooms.cbegin());
-        const auto gIdx = index(int(gIt - m_roomGroups.cbegin()), 0);
+        const auto rPos = int(rIt - gIt->rooms.begin());
+        const auto gIdx = index(int(gIt - m_roomGroups.begin()), 0);
         beginInsertRows(gIdx, rPos, rPos);
         gIt->rooms.insert(rIt, room);
         endInsertRows();
         m_roomIndices.insert(room, index(rPos, 0, gIdx));
-        qDebug() << "RoomListModel: Added" << room->objectName()
-                 << "to group" << gIt->key.toString();
+        qCDebug(MODELS) << "RoomListModel: Added" << room->objectName()
+                        << "to group" << gIt->key.toString();
     }
 }
 
@@ -236,21 +230,24 @@ void RoomListModel::connectRoomSignals(Room* room)
 {
     connect(room, &Room::beforeDestruction, this, &RoomListModel::deleteRoom);
     m_roomOrder->connectSignals(room);
-    connect(room, &Room::displaynameChanged,
-            this, [this,room] { refresh(room); });
-    connect(room, &Room::unreadMessagesChanged,
-            this, [this,room] { refresh(room); });
-    connect(room, &Room::notificationCountChanged,
-            this, [this,room] { refresh(room); });
-    connect(room, &Room::avatarChanged,
-            this, [this,room] { refresh(room, { Qt::DecorationRole }); });
+    connect(room, &Room::changed, this, [this, room](Room::Changes changes) {
+        using C = Room::Change;
+        if ((changes
+             & (C::RoomNames | C::PartiallyReadStats | C::UnreadStats
+                | C::Highlights))
+            > 0)
+            refresh(room);
+        else if (changes & C::Avatar)
+            refresh(room, { Qt::DecorationRole });
+    });
 }
 
 void RoomListModel::doRemoveRoom(const QModelIndex &idx)
 {
     if (!isValidRoomIndex(idx))
     {
-        qCritical() << "Attempt to remove a room at invalid index" << idx;
+        qCCritical(MODELS) << "Attempt to remove a room at invalid index"
+                           << idx;
         Q_ASSERT(false);
         return;
     }
@@ -258,12 +255,13 @@ void RoomListModel::doRemoveRoom(const QModelIndex &idx)
     auto& group = m_roomGroups[gPos]; // clazy:exclude=detaching-member
     const auto rIt =
         group.rooms.begin() + idx.row(); // clazy:exclude=detaching-member
-    qDebug() << "RoomListModel: Removing room" << (*rIt)->objectName()
-             << "from group" << group.key.toString();
+    qCDebug(MODELS) << "RoomListModel: Removing room" << (*rIt)->objectName()
+                    << "from group" << group.key.toString();
     if (m_roomIndices.remove(*rIt, idx) != 1)
     {
-        qCritical() << "Index" << idx << "for room" << (*rIt)->objectName()
-                    << "not found in the index registry";
+        qCCritical(MODELS) << "Index" << idx << "for room"
+                           << (*rIt)->objectName()
+                           << "not found in the index registry";
         Q_ASSERT(false);
     }
     beginRemoveRows(idx.parent(), idx.row(), idx.row());
@@ -347,6 +345,12 @@ bool RoomListModel::isValidRoomIndex(const QModelIndex& i) const
             i.row() < m_roomGroups[i.parent().row()].rooms.size();
 }
 
+inline QString toUiString(qsizetype n, const char* prefix = "",
+                          const QLocale& locale = QLocale())
+{
+    return n ? prefix % locale.toString(n) : QString();
+}
+
 QVariant RoomListModel::data(const QModelIndex& index, int role) const
 {
     if (!index.isValid())
@@ -357,8 +361,8 @@ QVariant RoomListModel::data(const QModelIndex& index, int role) const
     {
         if (role == Qt::DisplayRole) {
             int unreadRoomsCount = 0;
-            for (auto &r: m_roomGroups[index.row()].rooms)
-                unreadRoomsCount += r->unreadCount() != -1;
+            for (const auto& r: m_roomGroups[index.row()].rooms)
+                unreadRoomsCount += !r->unreadStats().empty();
 
             const auto postfix = unreadRoomsCount
                 ? QStringLiteral(" [%1]").arg(unreadRoomsCount) : QString();
@@ -406,27 +410,40 @@ QVariant RoomListModel::data(const QModelIndex& index, int role) const
     {
         case Qt::DisplayRole: {
             static Quotient::Settings settings;
-            auto unreadCount = room->unreadCount();
-            auto notifCount = room->notificationCount();
-            auto unreadTilReadReceipt = unreadCount - notifCount;
             QString value =
                 (room->isUnstable() ? "(!)" : "") % disambiguatedName;
-            if (unreadCount >= 0)
-                value += " ["
-                    % (unreadTilReadReceipt > 0
-                           ? QLocale().toString(unreadTilReadReceipt)
+            if (const auto& partiallyReadStats = room->partiallyReadStats();
+                !partiallyReadStats.empty()) //
+            {
+                const auto& [countSinceFullyRead, _1, isPartiallyReadEstimate] =
+                    partiallyReadStats;
+                const auto& [unreadCount, highlightCount, isUnreadEstimate] =
+                    room->unreadStats();
+                const auto partiallyReadCount =
+                    countSinceFullyRead - unreadCount;
+                value +=
+                    " [" % toUiString(unreadCount)
+                    % (!isPartiallyReadEstimate && isUnreadEstimate ? "?" : "")
+                    % (partiallyReadCount > 0
+                           ? QStringLiteral("+%L1").arg(partiallyReadCount)
+                           : QString())
+                    % (isPartiallyReadEstimate ? "?" : "")
+                    % (highlightCount > 0
+                           ? QStringLiteral(", %L1").arg(highlightCount)
                            : QString())
-                    % (room->readMarker() == room->historyEdge() ? "?" : "")
-                    % (notifCount > 0 ? QStringLiteral("+%L1").arg(notifCount)
-                                      : QString())
                     % ']';
-            if (settings.get("Debug/read_receipts", false)) {
-                auto localReadReceipt = room->readMarker(room->localUser());
-                value += " <"
-                    % QString::number(room->historyEdge() - localReadReceipt)
-                    % '|'
-                    % QString::number(room->syncEdge() - localReadReceipt.base())
-                    % '>';
+            }
+            if (settings.get("Debug/read_receipts", false)
+                && room->timelineSize() > 0)
+            {
+                const auto localReadReceipt = room->localReadReceiptMarker();
+                value += " {"
+                         % toUiString(room->historyEdge() - localReadReceipt,
+                                      "", QLocale::C)
+                         % '|'
+                         % toUiString(room->syncEdge() - localReadReceipt.base(),
+                                      "", QLocale::C)
+                         % '}';
             }
             return value;
         }
@@ -487,45 +504,44 @@ QVariant RoomListModel::data(const QModelIndex& index, int role) const
                                        " (use room settings for that)");
             }
 
-            if (const auto unreadCount = room->unreadCount(); unreadCount >= 0) {
-                // TODO for 0.0.96: tr("Messages after fully read marker: %L1")
-                result += "<br/>" % tr("Unread messages: %L1")
-                                    .arg(unreadCount);
-                if (room->readMarker() == room->historyEdge())
-                    result += ' ' % /*: Unread messages */ tr("(maybe more)");
-            }
+            static const QString MaybeMore = ' ' %
+                /*: Unread messages */ tr("(maybe more)");
+            if (const auto s = room->partiallyReadStats(); !s.empty())
+                result += "<br/>"
+                          % tr("Events after fully read marker: %L1")
+                                .arg(s.notableCount)
+                          % (s.isEstimate ? MaybeMore : QString());
 
-            // TODO for 0.0.96: tr("Unread notifications since read receipt: %L1")
-            if (const auto nfCount = room->notificationCount(); nfCount > 0)
-                result += "<br>" % tr("Unread notifications: %L1").arg(nfCount);
-
-            if (const auto hlCount = room->highlightCount(); hlCount > 0)
-                result += "<br>" % tr("Unread highlights: %L1").arg(hlCount);
+            if (const auto us = room->unreadStats(); !us.empty())
+                result += "<br>"
+                          % (room->highlightCount() > 0
+                                 ? tr("Unread events/highlights since read "
+                                      "receipt: %L1/%L2")
+                                       .arg(us.notableCount)
+                                       .arg(room->highlightCount())
+                                 : tr("Unread events since read receipt: %L1")
+                                       .arg(us.notableCount))
+                          % (us.isEstimate ? MaybeMore : QString());
 
             // Room ids are pretty safe from rogue HTML; escape it just in case
-            result +=
-                "<br>" % tr("ID: %1").arg(room->id().toHtmlEscaped()) % "<br>";
-            switch (room->joinState())
-            {
-                case JoinState::Join:
-                    result += tr("You joined this room");
-                    break;
-                case JoinState::Leave:
-                    result += tr("You left this room");
-                    break;
-                case JoinState::Invite:
-                    result += tr("You were invited into this room");
-            }
+            result += "<br>" % tr("Room id: %1").arg(room->id().toHtmlEscaped())
+                      % "<br>"
+                      % (room->joinState() == JoinState::Join
+                             ? tr("You joined this room as %1")
+                         : room->joinState() == JoinState::Invite
+                             ? tr("You were invited into this room as %1")
+                             : tr("You left this room as %1"))
+                        .arg(room->localUser()->id().toHtmlEscaped());
             return result;
         }
         case HasUnreadRole:
-            return room->unreadCount() > 0;
+            return !room->unreadStats().empty();
         case HighlightCountRole:
             return room->highlightCount();
         case JoinStateRole:
             if (!room->successorId().isEmpty())
                 return QStringLiteral("upgraded");
-            return toCString(room->joinState()); // TODO: drop toCString once on lib 0.7
+            return QVariant::fromValue(room->joinState());
         case ObjectRole:
             return QVariant::fromValue(room);
         default:
@@ -569,7 +585,8 @@ void RoomListModel::updateGroups(Room* room)
     }
     if (!groups.empty())
         addRoomToGroups(room, groups); // Groups the room wasn't before
-    qDebug() << "RoomListModel: groups for" << room->objectName() << "updated";
+    qCDebug(MODELS) << "RoomListModel: groups for" << room->objectName()
+                    << "updated";
 }
 
 void RoomListModel::refresh(Room* room, const QVector<int>& roles)
