@@ -1,19 +1,8 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2016 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2016 Felix Rohrbach <kde@fxrh.de>                        *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
@@ -21,8 +10,10 @@
 
 #include "abstractroomordering.h"
 #include "../quaternionroom.h"
-#include <connection.h>
-#include <util.h>
+
+#include <Quotient/connection.h>
+#include <Quotient/util.h>
+#include <Quotient/qt_connection_util.h>
 
 #include <QtCore/QAbstractItemModel>
 #include <QtCore/QMultiHash>
