@@ -1,25 +1,15 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2015 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2015 Felix Rohrbach <kde@fxrh.de>                        *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
 #include "userlistmodel.h"
 
-#include <QElapsedTimer>
+#include "../logging_categories.h"
+
 #include <QtCore/QDebug>
 #include <QtGui/QPixmap>
 #include <QtGui/QPalette>
@@ -28,9 +18,9 @@
 // provides avatar decorations depends on the delegate size
 #include <QtWidgets/QAbstractItemView>
 
-#include <connection.h>
-#include <room.h>
-#include <user.h>
+#include <Quotient/connection.h>
+#include <Quotient/room.h>
+#include <Quotient/user.h>
 
 UserListModel::UserListModel(QAbstractItemView* parent)
     : QAbstractListModel(parent), m_currentRoom(nullptr)
@@ -59,16 +49,12 @@ void UserListModel::setRoom(Quotient::Room* room)
         connect(m_currentRoom, &Room::memberAboutToRename, this, &UserListModel::userRemoved);
         connect(m_currentRoom, &Room::memberRenamed, this, &UserListModel::userAdded);
         connect(m_currentRoom, &Room::memberListChanged, this, &UserListModel::membersChanged);
+        connect(m_currentRoom, &Room::memberAvatarChanged, this, &UserListModel::avatarChanged);
+        connect(m_currentRoom->connection(), &Connection::loggedOut, this,
+                [this] { setRoom(nullptr); });
 
         filter({});
-
-        for (auto* user: std::as_const(m_users))
-            connect(user, &User::avatarChanged, this,
-                    &UserListModel::avatarChanged);
-
-        connect(m_currentRoom->connection(), &Connection::loggedOut, this,
-                [=] { setRoom(nullptr); });
-        qDebug() << m_users.count() << "user(s) in the room";
+        qCDebug(MODELS) << m_users.count() << "user(s) in the room";
     }
     endResetModel();
 }
@@ -87,7 +73,8 @@ QVariant UserListModel::data(const QModelIndex& index, int role) const
 
     if( index.row() >= m_users.count() )
     {
-        qDebug() << "UserListModel, something's wrong: index.row() >= m_users.count()";
+        qCWarning(MODELS) << "UserListModel, something's wrong: index.row() >= "
+                             "m_users.count()";
         return QVariant();
     }
     auto user = m_users.at(index.row());
@@ -146,14 +133,13 @@ void UserListModel::userAdded(Quotient::User* user)
     auto pos = findUserPos(user);
     if (pos != m_users.size() && m_users[pos] == user)
     {
-        qWarning() << "Trying to add the user" << user->id()
-                   << "but it's already in the user list";
+        qCWarning(MODELS) << "Trying to add the user" << user->id()
+                          << "but it's already in the user list";
         return;
     }
     beginInsertRows(QModelIndex(), pos, pos);
     m_users.insert(pos, user);
     endInsertRows();
-    connect( user, &Quotient::User::avatarChanged, this, &UserListModel::avatarChanged );
 }
 
 void UserListModel::userRemoved(Quotient::User* user)
@@ -161,8 +147,9 @@ void UserListModel::userRemoved(Quotient::User* user)
     auto pos = findUserPos(user);
     if (pos == m_users.size())
     {
-        qWarning() << "Trying to remove a room member not in the user list:"
-                   << user->id();
+        qCWarning(MODELS)
+            << "Trying to remove a room member not in the user list:"
+            << user->id();
         return;
     }
 
@@ -190,8 +177,8 @@ void UserListModel::filter(const QString& filterString)
     std::sort(m_users.begin(), m_users.end(), m_currentRoom->memberSorter());
     endResetModel();
 
-    qDebug() << "Filtering" << m_users.size() << "user(s) in"
-                << m_currentRoom->displayName() << "took" << et;
+    qCDebug(MODELS) << "Filtering" << m_users.size() << "user(s) in"
+                    << m_currentRoom->displayName() << "took" << et;
 }
 
 void UserListModel::refresh(Quotient::User* user, QVector<int> roles)
@@ -200,19 +187,18 @@ void UserListModel::refresh(Quotient::User* user, QVector<int> roles)
     if ( pos != m_users.size() )
         emit dataChanged(index(pos), index(pos), roles);
     else
-        qWarning() << "Trying to access a room member not in the user list";
+        qCWarning(MODELS)
+            << "Trying to access a room member not in the user list";
 }
 
-void UserListModel::avatarChanged(Quotient::User* user,
-                                  const Quotient::Room* context)
+void UserListModel::avatarChanged(Quotient::User* user)
 {
-    if (context == m_currentRoom)
-        refresh(user, {Qt::DecorationRole});
+    refresh(user, {Qt::DecorationRole});
 }
 
 int UserListModel::findUserPos(User* user) const
 {
-    return findUserPos(m_currentRoom->roomMembername(user));
+    return findUserPos(m_currentRoom->disambiguatedMemberName(user->id()));
 }
 
 int UserListModel::findUserPos(const QString& username) const
