@@ -1,30 +1,20 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2016 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2016 Felix Rohrbach <kde@fxrh.de>              *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
 #pragma once
 
-#include <room.h>
+#include <Quotient/room.h>
 
 class QuaternionRoom: public Quotient::Room
 {
         Q_OBJECT
         Q_PROPERTY(QString htmlSafeDisplayName READ htmlSafeDisplayName NOTIFY htmlSafeDisplayNameChanged)
+        Q_PROPERTY(int requestedEventsCount READ requestedEventsCount NOTIFY requestedEventsCountChanged)
     public:
         QuaternionRoom(Quotient::Connection* connection,
                        QString roomId, Quotient::JoinState joinState);
@@ -40,16 +30,24 @@ class QuaternionRoom: public Quotient::Room
                                       bool force = false);
 
         QString htmlSafeDisplayName() const;
+        int requestedEventsCount() const;
+
+    public slots:
+        // TODO, 0.0.96: move logic to libQuotient 0.9 and get rid of it here
+        void getHistory(int limit);
 
     signals:
         // Gotta wrap the Room::namesChanged signal because it has parameters
         // and moc cannot use signals with parameters defined in the parent
         // class as NOTIFY targets
         void htmlSafeDisplayNameChanged();
+        // TODO, 0.0.96: same as for getHistory()
+        void requestedEventsCountChanged();
 
     private:
         QSet<const Quotient::RoomEvent*> highlights;
         QString m_cachedUserFilter;
+        int m_requestedEventsCount = 0;
 
         void onAddNewTimelineEvents(timeline_iter_t from) override;
         void onAddHistoricalTimelineEvents(rev_iter_t from) override;
