@@ -1,34 +1,23 @@
-/******************************************************************************
- * Copyright (C) 2017 Kitsune Ral <kitsune-ral@users.sf.net>
+/*
+ * SPDX-FileCopyrightText: 2017 Kitsune Ral <kitsune-ral@users.sf.net>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Lesser General Public
- * License as published by the Free Software Foundation; either
- * version 2.1 of the License, or (at your option) any later version.
- *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Lesser General Public License for more details.
- *
- * You should have received a copy of the GNU Lesser General Public
- * License along with this library; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  */
 
 #include "roomdialogs.h"
 
 #include "mainwindow.h"
 #include "quaternionroom.h"
-#include "accountregistry.h"
 #include "accountselector.h"
 #include "models/orderbytag.h" // For tagToCaption()
+#include "logging_categories.h"
 
-#include <user.h>
-#include <connection.h>
-#include <csapi/create_room.h>
-#include <logging.h>
-#include <events/roompowerlevelsevent.h>
+#include <Quotient/accountregistry.h>
+#include <Quotient/user.h>
+#include <Quotient/connection.h>
+#include <Quotient/qt_connection_util.h>
+#include <Quotient/csapi/create_room.h>
+#include <Quotient/events/roompowerlevelsevent.h>
 
 #include <QtWidgets/QComboBox>
 #include <QtWidgets/QLineEdit>
@@ -194,7 +183,7 @@ RoomSettingsDialog::RoomSettingsDialog(QuaternionRoom* room, MainWindow* parent)
     {
         auto* changeActionButton =
                 new QPushButton(tr("Upgrade", "Upgrade a room version"));
-        connect(changeActionButton, &QAbstractButton::clicked, this, [=] {
+        connect(changeActionButton, &QAbstractButton::clicked, this, [this, room] {
             Dialog chooseVersionDlg(tr("Choose new room version"), this,
                     NoStatusLine, tr("Upgrade", "Upgrade a room version"),
                     NoExtraButtons);
@@ -241,16 +230,18 @@ RoomSettingsDialog::RoomSettingsDialog(QuaternionRoom* room, MainWindow* parent)
 
 void RoomSettingsDialog::load()
 {
-    const auto* plEvt =
-        room->getCurrentState<Quotient::RoomPowerLevelsEvent>();
-    const int userPl = plEvt->powerLevelForUser(room->localUser()->id());
+    if (const auto* plEvt =
+        room->currentState().get<Quotient::RoomPowerLevelsEvent>()) {
+        const int userPl = plEvt->powerLevelForUser(room->localUser()->id());
 
-    roomName->setText(room->name());
-    roomName->setReadOnly(plEvt && plEvt->powerLevelForState("m.room.name") > userPl);
-    alias->setText(room->canonicalAlias());
-    alias->setReadOnly(plEvt && plEvt->powerLevelForState("m.room.canonical_alias") > userPl);
-    topic->setPlainText(room->topic());
-    topic->setReadOnly(plEvt && plEvt->powerLevelForState("m.room.topic") > userPl);
+        roomName->setText(room->name());
+        roomName->setReadOnly(plEvt->powerLevelForState("m.room.name") > userPl);
+        alias->setText(room->canonicalAlias());
+        alias->setReadOnly(plEvt->powerLevelForState("m.room.canonical_alias")
+                           > userPl);
+        topic->setPlainText(room->topic());
+        topic->setReadOnly(plEvt->powerLevelForState("m.room.topic") > userPl);
+    }
     // QPlainTextEdit may change some characters before any editing occurs;
     // so save this already adjusted topic to compare later.
     previousTopic = topic->toPlainText();
@@ -353,16 +344,18 @@ class InviteeList : public QListWidget
         }
 };
 
-CreateRoomDialog::CreateRoomDialog(const AccountRegistry* accounts, QWidget* parent)
-    : RoomDialogBase(tr("Create room"), tr("Create room"),
-                     nullptr, parent, NoExtraButtons)
+CreateRoomDialog::CreateRoomDialog(Quotient::AccountRegistry* accounts,
+                                   QWidget* parent)
+    : RoomDialogBase(tr("Create room"), tr("Create room"), nullptr, parent,
+                     NoExtraButtons)
     , accountChooser(new AccountSelector(accounts))
     , version(nullptr) // Will be initialized below
     , nextInvitee(new NextInvitee)
-    , inviteButton(new QPushButton(tr("Add", "Add a user to the list of invitees")))
+    , inviteButton(
+          new QPushButton(tr("Add", "Add a user to the list of invitees")))
     , invitees(new QListWidget)
 {
-    Q_ASSERT(accounts && !accounts->isEmpty());
+    Q_ASSERT(!accounts->empty());
 
     auto* versionBox = new QHBoxLayout;
     version = addVersionSelector(versionBox);
@@ -433,7 +426,6 @@ void CreateRoomDialog::updatePushButtons()
 
 void CreateRoomDialog::load()
 {
-    qDebug() << "Loading the dialog";
     roomName->clear();
     alias->clear();
     topic->clear();
@@ -508,9 +500,9 @@ void CreateRoomDialog::accountSwitched()
                 model->appendRow(item);
             }
         }
-        qDebug() << "Completion candidates:" << model->rowCount()
-                 << "out of" << connection->users().size()
-                 << "filled in" << et;
+        qCDebug(MAIN) << "Completion candidates:" << model->rowCount()
+                      << "out of" << connection->users().size() << "filled in"
+                      << et;
 //    }
     }
     nextInvitee->setModel(model);
