@@ -125,18 +125,6 @@
         <source>Send a message (over %1) or enter a command...</source>
         <translation>Sende eine Nachricht (über %1) oder gebe einen Befehl ein …</translation>
     </message>
-    <message>
-        <source>Attaching an image from clipboard</source>
-        <translation>Anhängen eines Bildes aus der Zwischenablage</translation>
-    </message>
-    <message>
-        <source>Send a message (no end-to-end encryption support yet)...</source>
-        <translation>Eine Nachricht senden (noch keine Unterstützung für Ende-zu-Ende-Verschlüsselung) …</translation>
-    </message>
-    <message>
-        <source>Your build of Quaternion doesn&apos;t support Markdown</source>
-        <translation>Ihr Build von Quaternion unterstützt Markdown nicht</translation>
-    </message>
     <message>
         <source>No completions</source>
         <translation>Keine Vervollständigungen</translation>
@@ -164,6 +152,14 @@
         <source>%L1 more</source>
         <translation>%L1 weitere</translation>
     </message>
+    <message>
+        <source>%1 is not readable or not a file</source>
+        <translation>%1 ist nicht lesbar oder keine Datei</translation>
+    </message>
+    <message>
+        <source>Attaching the pasted image</source>
+        <translation>Anhängen des eingefügten Bildes</translation>
+    </message>
 </context>
 <context>
     <name>Timeline</name>
@@ -360,6 +356,22 @@ Einstellungen</translation>
         <source>Getting supported login flows...</source>
         <translation>Lade unterstützte Anmeldemethoden …</translation>
     </message>
+    <message>
+        <source>This account is logged in already</source>
+        <translation>Dieses Konto ist bereits angemeldet</translation>
+    </message>
+    <message>
+        <source>(none)</source>
+        <translation>(keiner)</translation>
+    </message>
+    <message>
+        <source>Saved device id</source>
+        <translation>Gespeicherte Geräte-ID</translation>
+    </message>
+    <message>
+        <source>Enable E2EE (BETA)</source>
+        <translation>E2EE einschalten (BETA)</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -383,10 +395,6 @@ Einstellungen</translation>
         <source>&amp;View</source>
         <translation>&amp;Oberfläche</translation>
     </message>
-    <message>
-        <source>Dock &amp;panels</source>
-        <translation>&amp;Panel anheften</translation>
-    </message>
     <message>
         <source>&amp;Display in timeline</source>
         <translation>In &amp;Historie anzeigen</translation>
@@ -499,22 +507,6 @@ Einstellungen</translation>
         <source>Configure &amp;network proxy...</source>
         <translation>Konfiguriere &amp;Netzwerk-Proxy …</translation>
     </message>
-    <message>
-        <source>Couldn&apos;t open a file to save access token</source>
-        <translation>Konnte keine Datei öffnen, um den Zugriffstoken zu speichern</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t open a file to write the access token to. You&apos;re logged in but will have to provide your password again when you restart the application.</source>
-        <translation>Quaternion konnte keine Datei öffnen, um den Zugangs-Token darin zu speichern. Sie wurden angemeldet, werden aber erneut ein Passwort eingeben müssen, wenn Sie die Anwendung neu starten.</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t set access token file permissions</source>
-        <translation>Konnte Berechtigungen der Zugriffstokendatei nicht setzen</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t restrict permissions on the access token file. Do you still want to save the access token to it?</source>
-        <translation>Quaternion konnte die Berechtigungen zur Zugangstoken-Datei nicht einschränken. Soll der Zugangstoken trotzdem darin gespeichert werden?</translation>
-    </message>
     <message>
         <source>Logged out as %1</source>
         <translation>Als %1 abgemeldet</translation>
@@ -677,34 +669,6 @@ Antwort:
         <source>Open a room from the room list</source>
         <translation>Einen Raum aus der Raumliste öffnen</translation>
     </message>
-    <message>
-        <source>Show/hide Rooms dock panel</source>
-        <translation>Dock-Panel der Räume ein-/ausblenden</translation>
-    </message>
-    <message>
-        <source>Show/hide Users dock panel</source>
-        <translation>Benutzer-Dock-Panel ein-/ausblenden</translation>
-    </message>
-    <message>
-        <source>Access token file found</source>
-        <translation>Zugriffstokendatei gefunden</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t migrate access token</source>
-        <translation>Zugriffstoken konnte nicht migriert werden</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t save access token</source>
-        <translation>Zugriffstoken konnte nicht gespeichert werden.</translation>
-    </message>
-    <message>
-        <source>Logging in into a logged in account</source>
-        <translation>Einloggen in ein angemeldetes Konto</translation>
-    </message>
-    <message>
-        <source>You&apos;re trying to log in into an account that&apos;s already logged in. Do you want to continue?</source>
-        <translation>Sie versuchen, sich bei einem bereits angemeldeten Konto anzumelden. Möchten Sie fortfahren?</translation>
-    </message>
     <message>
         <source>Couldn&apos;t delete access token</source>
         <translation>Zugriffstoken konnte nicht gelöscht werden.</translation>
@@ -779,18 +743,6 @@ oder Alias (beginnend mit #)</translation>
         <source>libQuotient contributors @ GitHub</source>
         <translation>libQuotient Mitwirkende @ GitHub</translation>
     </message>
-    <message>
-        <source>Do you want to migrate the access token for %1 from the file to the keychain?</source>
-        <translation>Möchten Sie das Zugriffstoken für %1 aus der Datei in den Schlüsselbund migrieren?</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t migrate access token for %1 from the file to the keychain.</source>
-        <translation>Quaternion konnte das Zugriffstoken %1 aus der Datei nicht in den Schlüsselbund migrieren.</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t save the access token to the keychain. Do you want to save the access token to file %1?</source>
-        <translation>Quaternion konnte das Zugriffstoken nicht im Schlüsselbund speichern. Möchten Sie das Zugriffstoken in der Datei %1 speichern?</translation>
-    </message>
     <message>
         <source>First sync completed for %1</source>
         <translation>Erste Synchronisierung für %1 abgeschlossen</translation>
@@ -819,7 +771,7 @@ oder Alias (beginnend mit #)</translation>
 Is that right?</source>
         <translation>Eine externe Anwendung wird geöffnet, um einen Nicht-Matrix-Link zu besuchen: 
 
- % 1 
+%1 
 
  Ist das richtig?</translation>
     </message>
@@ -953,10 +905,6 @@ Benutzerdefinierte Etiketten sollten mit „u.“ beginnen.</translation>
         <source>The URI contains an action &apos;%1&apos; that cannot be applied to Matrix resource %2</source>
         <translation>Der URI enthält eine Aktion &apos;%1&apos;, die nicht auf die Matrix-Ressource %2 angewendet werden kann</translation>
     </message>
-    <message>
-        <source>Failed to resolve server %1</source>
-        <translation>Server %1 konnte nicht aufgelöst werden</translation>
-    </message>
     <message>
         <source>Room or user ID, room alias,
 Matrix URI or matrix.to link</source>
@@ -991,6 +939,29 @@ Matrix URI oder matrix.to Link</translation>
         <source>Show a confirmation box before opening non-Matrix links in an external application</source>
         <translation>Zeige ein Bestätigungsfeld vor dem Öffnen von Nicht-Matrix-Links in einer externen Anwendung an</translation>
     </message>
+    <message>
+        <source>Account %1 is synchronised, have a good chat</source>
+        <translation>Konto %1 ist synchronisiert, viel Spaß beim Chatten</translation>
+    </message>
+    <message numerus="yes">
+        <source>All %Ln accounts synchronised, have a good chat</source>
+        <translation>
+            <numerusform>%Ln Konto ist synchronisiert, viel Spaß beim Chatten</numerusform>
+            <numerusform>Alle %Ln Kontos sind synchronisiert, viel Spaß beim Chatten</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>&amp;Room list</source>
+        <translation>&amp;Raumliste</translation>
+    </message>
+    <message>
+        <source>&amp;Member list</source>
+        <translation>&amp;Mitgliederliste</translation>
+    </message>
+    <message>
+        <source>Dock panels</source>
+        <translation>Dock-Paneele</translation>
+    </message>
 </context>
 <context>
     <name>MessageEventModel</name>
@@ -1130,10 +1101,6 @@ Matrix URI oder matrix.to Link</translation>
         <source>created the room, version %1</source>
         <translation>erstellte den Raum, Version %1</translation>
     </message>
-    <message>
-        <source>has set room aliases on server %1 to: %2</source>
-        <translation>hat Raum-Aliase auf dem Server %1 auf %2 gesetzt</translation>
-    </message>
     <message>
         <source>banned %1 from the room: %2</source>
         <translation>verbannte %1 aus dem Raum: %2</translation>
@@ -1344,18 +1311,6 @@ Matrix URI oder matrix.to Link</translation>
         <source>%1 (as %2)</source>
         <translation>%1 (als %2)</translation>
     </message>
-    <message>
-        <source>You joined this room</source>
-        <translation>Sie sind diesem Raum beigetreten</translation>
-    </message>
-    <message>
-        <source>You left this room</source>
-        <translation>Sie haben diesen Raum verlassen</translation>
-    </message>
-    <message>
-        <source>You were invited into this room</source>
-        <translation>Sie wurden in diesen Raum eingeladen</translation>
-    </message>
     <message>
         <source>Main alias: %1</source>
         <translation>Hauptalias: %1</translation>
@@ -1368,10 +1323,6 @@ Matrix URI oder matrix.to Link</translation>
         <source>The room enforces encryption</source>
         <translation>Der Raum erzwingt Verschlüsselung</translation>
     </message>
-    <message>
-        <source>ID: %1</source>
-        <translation>ID: %1</translation>
-    </message>
     <message>
         <source>Favourites</source>
         <translation>Favoriten</translation>
@@ -1396,22 +1347,30 @@ Matrix URI oder matrix.to Link</translation>
         <source>Invited: %L1</source>
         <translation>Eingeladen: %L1</translation>
     </message>
-    <message>
-        <source>Unread messages: %L1</source>
-        <translation>Ungelesene Nachrichten: %L1</translation>
-    </message>
-    <message>
-        <source>Unread highlights: %L1</source>
-        <translation>Ungelesene Hervorhebungen: %L1</translation>
-    </message>
-    <message>
-        <source>Unread notifications: %L1</source>
-        <translation>Ungelesene Benachrichtigungen: %L1</translation>
-    </message>
     <message>
         <source>(maybe more)</source>
         <translation>(vielleicht mehr)</translation>
     </message>
+    <message>
+        <source>Events after fully read marker: %L1</source>
+        <translation>Ereignisse nach vollständig gelesenem Marker: %L1</translation>
+    </message>
+    <message>
+        <source>Room id: %1</source>
+        <translation>Raum-ID: %1</translation>
+    </message>
+    <message>
+        <source>You joined this room as %1</source>
+        <translation>Sie sind diesem Raum als %1 beigetreten</translation>
+    </message>
+    <message>
+        <source>You were invited into this room as %1</source>
+        <translation>Sie wurden als %1 in diesen Raum eingeladen</translation>
+    </message>
+    <message>
+        <source>You left this room as %1</source>
+        <translation>Sie haben diesen Raum als %1 verlassen</translation>
+    </message>
 </context>
 <context>
     <name>RoomSettingsDialog</name>
@@ -1622,18 +1581,6 @@ neuem Raum</translation>
         <source>Image request has been cancelled</source>
         <translation>Bildanfrage wurde abgebrochen</translation>
     </message>
-    <message>
-        <source>Media id &apos;%1&apos; doesn&apos;t follow server/mediaId pattern</source>
-        <translation>Die Medien-ID &apos;% 1&apos; folgt nicht dem Server/Medien-ID-Muster</translation>
-    </message>
-    <message>
-        <source>No connection to perform image request</source>
-        <translation>Keine Verbindung zum Durchführen einer Bildanforderung</translation>
-    </message>
-    <message>
-        <source>Image request is pending</source>
-        <translation>Bildanforderung ist ausstehend</translation>
-    </message>
 </context>
 <context>
     <name>TimelineWidget</name>
@@ -1759,5 +1706,55 @@ neuem Raum</translation>
         <source>Reset the current character formatting to the default</source>
         <translation>Zurücksetzen der aktuellen Zeichenformatierung auf die Standardeinstellung</translation>
     </message>
+    <message>
+        <source>Could not insert HTML - it&apos;s either invalid or unsupported</source>
+        <translation>HTML konnte nicht eingefügt werden – es ist entweder ungültig oder wird nicht unterstützt</translation>
+    </message>
+    <message>
+        <source>Paste as rich text</source>
+        <translation>Als Rich-Text einfügen</translation>
+    </message>
+    <message>
+        <source>Paste as plain text</source>
+        <translation>Als Klartext einfügen</translation>
+    </message>
+</context>
+<context>
+    <name>DockModeMenu</name>
+    <message>
+        <source>&amp;Off</source>
+        <translation>&amp;Aus</translation>
+    </message>
+    <message>
+        <source>&amp;Docked</source>
+        <translation>Ange&amp;dockt</translation>
+    </message>
+    <message>
+        <source>&amp;Floating</source>
+        <translation>&amp;Schwebend</translation>
+    </message>
+    <message>
+        <source>Completely hide this list</source>
+        <translation>Diese Liste vollständig ausblenden</translation>
+    </message>
+    <message>
+        <source>The list is shown within the main window</source>
+        <translation>Die Liste wird im Hauptfenster angezeigt</translation>
+    </message>
+    <message>
+        <source>The list is shown separately from the main window</source>
+        <translation>Die Liste wird getrennt vom Hauptfenster angezeigt</translation>
+    </message>
+</context>
+<context>
+    <name>AbstractThumbnailResponse</name>
+    <message>
+        <source>No connection to perform image request</source>
+        <translation>Keine Verbindung zum Durchführen einer Bildanforderung</translation>
+    </message>
+    <message>
+        <source>Image request is pending</source>
+        <translation>Bildanforderung ist ausstehend</translation>
+    </message>
 </context>
 </TS>
