@@ -83,7 +83,7 @@
     </message>
     <message>
         <source>Unknown /command. Use // to send this line literally</source>
-        <translation>Unknown /command. Use // to send this line literally</translation>
+        <translation>Unknown /command. Use // to send this line literally.</translation>
     </message>
     <message>
         <source>Attach</source>
@@ -125,18 +125,6 @@
         <source>Send a message (over %1) or enter a command...</source>
         <translation>Send a message (over %1) or enter a command...</translation>
     </message>
-    <message>
-        <source>Attaching an image from clipboard</source>
-        <translation>Attaching an image from clipboard</translation>
-    </message>
-    <message>
-        <source>Send a message (no end-to-end encryption support yet)...</source>
-        <translation>Send a message (no end-to-end encryption support yet)...</translation>
-    </message>
-    <message>
-        <source>Your build of Quaternion doesn&apos;t support Markdown</source>
-        <translation>Your build of Quaternion doesn&apos;t support Markdown</translation>
-    </message>
     <message>
         <source>No completions</source>
         <translation>No completions</translation>
@@ -164,6 +152,14 @@
         <source>%L1 more</source>
         <translation>%L1 more</translation>
     </message>
+    <message>
+        <source>%1 is not readable or not a file</source>
+        <translation>%1 is not readable or not a file</translation>
+    </message>
+    <message>
+        <source>Attaching the pasted image</source>
+        <translation>Attaching the pasted image</translation>
+    </message>
 </context>
 <context>
     <name>Timeline</name>
@@ -360,6 +356,22 @@ settings</translation>
         <source>Getting supported login flows...</source>
         <translation>Getting supported login flows...</translation>
     </message>
+    <message>
+        <source>This account is logged in already</source>
+        <translation>This account is logged in already</translation>
+    </message>
+    <message>
+        <source>(none)</source>
+        <translation>(none)</translation>
+    </message>
+    <message>
+        <source>Saved device id</source>
+        <translation>Saved device id</translation>
+    </message>
+    <message>
+        <source>Enable E2EE (BETA)</source>
+        <translation>Enable E2EE (BETA)</translation>
+    </message>
 </context>
 <context>
     <name>MainWindow</name>
@@ -383,10 +395,6 @@ settings</translation>
         <source>&amp;View</source>
         <translation>&amp;View</translation>
     </message>
-    <message>
-        <source>Dock &amp;panels</source>
-        <translation>Dock &amp;panels</translation>
-    </message>
     <message>
         <source>&amp;Display in timeline</source>
         <translation>&amp;Display in timeline</translation>
@@ -499,22 +507,6 @@ settings</translation>
         <source>Configure &amp;network proxy...</source>
         <translation>Configure &amp;network proxy...</translation>
     </message>
-    <message>
-        <source>Couldn&apos;t open a file to save access token</source>
-        <translation>Couldn&apos;t open a file to save access token</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t open a file to write the access token to. You&apos;re logged in but will have to provide your password again when you restart the application.</source>
-        <translation>Quaternion couldn&apos;t open a file to write the access token to. You&apos;re logged in but will have to provide your password again when you restart the application.</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t set access token file permissions</source>
-        <translation>Couldn&apos;t set access token file permissions</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t restrict permissions on the access token file. Do you still want to save the access token to it?</source>
-        <translation>Quaternion couldn&apos;t restrict permissions on the access token file. Do you still want to save the access token to it?</translation>
-    </message>
     <message>
         <source>Logged out as %1</source>
         <translation>Logged out as %1</translation>
@@ -677,34 +669,6 @@ Response:
         <source>Open a room from the room list</source>
         <translation>Open a room from the room list</translation>
     </message>
-    <message>
-        <source>Show/hide Rooms dock panel</source>
-        <translation>Show/hide Rooms dock panel</translation>
-    </message>
-    <message>
-        <source>Show/hide Users dock panel</source>
-        <translation>Show/hide Users dock panel</translation>
-    </message>
-    <message>
-        <source>Access token file found</source>
-        <translation>Access token file found</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t migrate access token</source>
-        <translation>Couldn&apos;t migrate access token</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t save access token</source>
-        <translation>Couldn&apos;t save access token</translation>
-    </message>
-    <message>
-        <source>Logging in into a logged in account</source>
-        <translation>Logging in into a logged in account</translation>
-    </message>
-    <message>
-        <source>You&apos;re trying to log in into an account that&apos;s already logged in. Do you want to continue?</source>
-        <translation>You&apos;re trying to log in into an account that&apos;s already logged in. Do you want to continue?</translation>
-    </message>
     <message>
         <source>Couldn&apos;t delete access token</source>
         <translation>Couldn&apos;t delete access token</translation>
@@ -779,18 +743,6 @@ or alias (starting with #)</translation>
         <source>libQuotient contributors @ GitHub</source>
         <translation>libQuotient contributors @ GitHub</translation>
     </message>
-    <message>
-        <source>Do you want to migrate the access token for %1 from the file to the keychain?</source>
-        <translation>Do you want to migrate the access token for %1 from the file to the keychain?</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t migrate access token for %1 from the file to the keychain.</source>
-        <translation>Quaternion couldn&apos;t migrate access token for %1 from the file to the keychain.</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t save the access token to the keychain. Do you want to save the access token to file %1?</source>
-        <translation>Quaternion couldn&apos;t save the access token to the keychain. Do you want to save the access token to file %1?</translation>
-    </message>
     <message>
         <source>First sync completed for %1</source>
         <translation>First sync completed for %1</translation>
@@ -953,10 +905,6 @@ User-defined tags should start with &quot;u.&quot;</translation>
         <source>The URI contains an action &apos;%1&apos; that cannot be applied to Matrix resource %2</source>
         <translation>The URI contains an action &apos;%1&apos; that cannot be applied to Matrix resource %2</translation>
     </message>
-    <message>
-        <source>Failed to resolve server %1</source>
-        <translation>Failed to resolve server %1</translation>
-    </message>
     <message>
         <source>Room or user ID, room alias,
 Matrix URI or matrix.to link</source>
@@ -991,6 +939,36 @@ Matrix URI or matrix.to link</translation>
         <source>Show a confirmation box before opening non-Matrix links in an external application</source>
         <translation>Show a confirmation box before opening non-Matrix links in an external application</translation>
     </message>
+    <message numerus="yes">
+        <source>Loading %Ln accounts, please wait</source>
+        <translation>
+            <numerusform>Loading %Ln account, please wait</numerusform>
+            <numerusform>Loading %Ln accounts, please wait</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>Account %1 is synchronised, have a good chat</source>
+        <translation>Account %1 is synchronised, have a good chat</translation>
+    </message>
+    <message numerus="yes">
+        <source>All %Ln accounts synchronised, have a good chat</source>
+        <translation>
+            <numerusform>%Ln account synchronised, have a good chat</numerusform>
+            <numerusform>All %Ln accounts synchronised, have a good chat</numerusform>
+        </translation>
+    </message>
+    <message>
+        <source>&amp;Room list</source>
+        <translation>&amp;Room list</translation>
+    </message>
+    <message>
+        <source>&amp;Member list</source>
+        <translation>&amp;Member list</translation>
+    </message>
+    <message>
+        <source>Dock panels</source>
+        <translation>Dock panels</translation>
+    </message>
 </context>
 <context>
     <name>MessageEventModel</name>
@@ -1130,10 +1108,6 @@ Matrix URI or matrix.to link</translation>
         <source>created the room, version %1</source>
         <translation>created the room, version %1</translation>
     </message>
-    <message>
-        <source>has set room aliases on server %1 to: %2</source>
-        <translation>has set room aliases on server %1 to: %2</translation>
-    </message>
     <message>
         <source>banned %1 from the room: %2</source>
         <translation>banned %1 from the room: %2</translation>
@@ -1344,18 +1318,6 @@ Matrix URI or matrix.to link</translation>
         <source>%1 (as %2)</source>
         <translation>%1 (as %2)</translation>
     </message>
-    <message>
-        <source>You joined this room</source>
-        <translation>You joined this room</translation>
-    </message>
-    <message>
-        <source>You left this room</source>
-        <translation>You left this room</translation>
-    </message>
-    <message>
-        <source>You were invited into this room</source>
-        <translation>You were invited into this room</translation>
-    </message>
     <message>
         <source>Main alias: %1</source>
         <translation>Main alias: %1</translation>
@@ -1368,10 +1330,6 @@ Matrix URI or matrix.to link</translation>
         <source>The room enforces encryption</source>
         <translation>The room enforces encryption</translation>
     </message>
-    <message>
-        <source>ID: %1</source>
-        <translation>ID: %1</translation>
-    </message>
     <message>
         <source>Favourites</source>
         <translation>Favourites</translation>
@@ -1396,22 +1354,38 @@ Matrix URI or matrix.to link</translation>
         <source>Invited: %L1</source>
         <translation>Invited: %L1</translation>
     </message>
-    <message>
-        <source>Unread messages: %L1</source>
-        <translation>Unread messages: %L1</translation>
-    </message>
-    <message>
-        <source>Unread highlights: %L1</source>
-        <translation>Unread highlights: %L1</translation>
-    </message>
-    <message>
-        <source>Unread notifications: %L1</source>
-        <translation>Unread notifications: %L1</translation>
-    </message>
     <message>
         <source>(maybe more)</source>
         <translation>(maybe more)</translation>
     </message>
+    <message>
+        <source>Events after fully read marker: %L1</source>
+        <translation>Events after fully read marker: %L1</translation>
+    </message>
+    <message>
+        <source>Unread events/highlights since read receipt: %L1/%L2</source>
+        <translation>Unread events/highlights since read receipt: %L1/%L2</translation>
+    </message>
+    <message>
+        <source>Unread events since read receipt: %L1</source>
+        <translation>Unread events since read receipt: %L1</translation>
+    </message>
+    <message>
+        <source>Room id: %1</source>
+        <translation>Room id: %1</translation>
+    </message>
+    <message>
+        <source>You joined this room as %1</source>
+        <translation>You joined this room as %1</translation>
+    </message>
+    <message>
+        <source>You were invited into this room as %1</source>
+        <translation>You were invited into this room as %1</translation>
+    </message>
+    <message>
+        <source>You left this room as %1</source>
+        <translation>You left this room as %1</translation>
+    </message>
 </context>
 <context>
     <name>RoomSettingsDialog</name>
@@ -1622,18 +1596,6 @@ new room</translation>
         <source>Image request has been cancelled</source>
         <translation>Image request has been cancelled</translation>
     </message>
-    <message>
-        <source>Media id &apos;%1&apos; doesn&apos;t follow server/mediaId pattern</source>
-        <translation>Media id &apos;%1&apos; doesn&apos;t follow server/mediaId pattern</translation>
-    </message>
-    <message>
-        <source>No connection to perform image request</source>
-        <translation>No connection to perform image request</translation>
-    </message>
-    <message>
-        <source>Image request is pending</source>
-        <translation>Image request is pending</translation>
-    </message>
 </context>
 <context>
     <name>TimelineWidget</name>
@@ -1759,5 +1721,55 @@ new room</translation>
         <source>Reset the current character formatting to the default</source>
         <translation>Reset the current character formatting to the default</translation>
     </message>
+    <message>
+        <source>Could not insert HTML - it&apos;s either invalid or unsupported</source>
+        <translation>Could not insert HTML - it&apos;s either invalid or unsupported</translation>
+    </message>
+    <message>
+        <source>Paste as rich text</source>
+        <translation>Paste as rich text</translation>
+    </message>
+    <message>
+        <source>Paste as plain text</source>
+        <translation>Paste as plain text</translation>
+    </message>
+</context>
+<context>
+    <name>DockModeMenu</name>
+    <message>
+        <source>&amp;Off</source>
+        <translation>&amp;Off</translation>
+    </message>
+    <message>
+        <source>&amp;Docked</source>
+        <translation>&amp;Docked</translation>
+    </message>
+    <message>
+        <source>&amp;Floating</source>
+        <translation>&amp;Floating</translation>
+    </message>
+    <message>
+        <source>Completely hide this list</source>
+        <translation>Completely hide this list</translation>
+    </message>
+    <message>
+        <source>The list is shown within the main window</source>
+        <translation>The list is shown within the main window</translation>
+    </message>
+    <message>
+        <source>The list is shown separately from the main window</source>
+        <translation>The list is shown separately from the main window</translation>
+    </message>
+</context>
+<context>
+    <name>AbstractThumbnailResponse</name>
+    <message>
+        <source>No connection to perform image request</source>
+        <translation>No connection to perform image request</translation>
+    </message>
+    <message>
+        <source>Image request is pending</source>
+        <translation>Image request is pending</translation>
+    </message>
 </context>
 </TS>
