@@ -287,10 +287,6 @@ de sala</translation>
         <source>&amp;View</source>
         <translation>&amp;Ver</translation>
     </message>
-    <message>
-        <source>Dock &amp;panels</source>
-        <translation>Dock &amp;paneles</translation>
-    </message>
     <message>
         <source>&amp;Display in timeline</source>
         <translation>&amp;Mostrar en la línea de tiempo</translation>
@@ -403,22 +399,6 @@ de sala</translation>
         <source>Configure &amp;network proxy...</source>
         <translation>Configurar el proxy de la &amp;red...</translation>
     </message>
-    <message>
-        <source>Couldn&apos;t open a file to save access token</source>
-        <translation>No se pudo abrir un archivo para guardar el token de acceso</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t open a file to write the access token to. You&apos;re logged in but will have to provide your password again when you restart the application.</source>
-        <translation>Quaternion no pudo abrir un archivo para escribir el token de acceso. Ha iniciado sesión pero tendrá que proporcionar su contraseña nuevamente cuando reinicie la aplicación.</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t set access token file permissions</source>
-        <translation>No se pudieron establecer los permisos del archivo de token de acceso</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t restrict permissions on the access token file. Do you still want to save the access token to it?</source>
-        <translation>Quaternion no pudo restringir los permisos en el archivo de token de acceso. ¿Todavía quieres guardar el token de acceso?</translation>
-    </message>
     <message>
         <source>Logged out as %1</source>
         <translation>Se ha cerrado la sesión como %1</translation>
@@ -581,34 +561,6 @@ Response:
         <source>Open a room from the room list</source>
         <translation>Abrir una sala de la lista de salas</translation>
     </message>
-    <message>
-        <source>Show/hide Rooms dock panel</source>
-        <translation>Mostrar / ocultar panel de acoplamiento de salas</translation>
-    </message>
-    <message>
-        <source>Show/hide Users dock panel</source>
-        <translation>Mostrar/ocultar el panel de acoplamiento Usuarios</translation>
-    </message>
-    <message>
-        <source>Access token file found</source>
-        <translation>Se encontró el archivo de token de acceso</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t migrate access token</source>
-        <translation>No se pudo migrar el token de acceso</translation>
-    </message>
-    <message>
-        <source>Couldn&apos;t save access token</source>
-        <translation>No se pudo guardar el token de acceso</translation>
-    </message>
-    <message>
-        <source>Logging in into a logged in account</source>
-        <translation>Iniciar sesión en una cuenta iniciada</translation>
-    </message>
-    <message>
-        <source>You&apos;re trying to log in into an account that&apos;s already logged in. Do you want to continue?</source>
-        <translation>Está intentando iniciar sesión en una cuenta que ya ha iniciado sesión. ¿Desea continuar?</translation>
-    </message>
     <message>
         <source>Couldn&apos;t delete access token</source>
         <translation>No se pudo eliminar el token de acceso</translation>
@@ -683,18 +635,6 @@ o alias (comenzando con #)</translation>
         <source>libQuotient contributors @ GitHub</source>
         <translation>Colaboradores de libQuotient en @ GitHub</translation>
     </message>
-    <message>
-        <source>Do you want to migrate the access token for %1 from the file to the keychain?</source>
-        <translation>¿Desea migrar el token de acceso para %1 del archivo al llavero?</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t migrate access token for %1 from the file to the keychain.</source>
-        <translation>Quaternion no pudo migrar el token de acceso %1 del archivo al llavero.</translation>
-    </message>
-    <message>
-        <source>Quaternion couldn&apos;t save the access token to the keychain. Do you want to save the access token to file %1?</source>
-        <translation>Quaternion no pudo guardar el token de acceso en el llavero. ¿Desea guardar el token de acceso en un archivo %1?</translation>
-    </message>
     <message>
         <source>First sync completed for %1</source>
         <translation>Primera sincronización completada para %1</translation>
@@ -886,10 +826,6 @@ Matrix URI o enlace matriz.to</translation>
         <source>created the room, version %1</source>
         <translation>creada la sala, versión %1</translation>
     </message>
-    <message>
-        <source>has set room aliases on server %1 to: %2</source>
-        <translation>ha establecido alias de sala en el servidor %1 a: %2</translation>
-    </message>
     <message>
         <source>banned %1 from the room: %2</source>
         <translation>suspendido %1 de la sala: %2</translation>
@@ -1085,18 +1021,6 @@ Matrix URI o enlace matriz.to</translation>
         <source>%1 (as %2)</source>
         <translation>%1 (como %2)</translation>
     </message>
-    <message>
-        <source>You joined this room</source>
-        <translation>Te uniste a esta sala</translation>
-    </message>
-    <message>
-        <source>You left this room</source>
-        <translation>Saliste de esta sala.</translation>
-    </message>
-    <message>
-        <source>You were invited into this room</source>
-        <translation>Fuiste invitado a esta sala</translation>
-    </message>
     <message>
         <source>Main alias: %1</source>
         <translation>Alias principal: %1</translation>
@@ -1109,10 +1033,6 @@ Matrix URI o enlace matriz.to</translation>
         <source>The room enforces encryption</source>
         <translation>La sala impone el cifrado</translation>
     </message>
-    <message>
-        <source>ID: %1</source>
-        <translation>ID: %1</translation>
-    </message>
     <message>
         <source>Favourites</source>
         <translation>Favoritos</translation>
@@ -1311,14 +1231,6 @@ Esta operación no se puede revertir.</translation>
         <source>Image request has been cancelled</source>
         <translation>La solicitud de imagen ha sido cancelada</translation>
     </message>
-    <message>
-        <source>Media id &apos;%1&apos; doesn&apos;t follow server/mediaId pattern</source>
-        <translation>El id de medios &apos;%1&apos; no sigue el patrón server/mediaId</translation>
-    </message>
-    <message>
-        <source>No connection to perform image request</source>
-        <translation>No hay conexión para realizar una solicitud de imagen</translation>
-    </message>
 </context>
 <context>
     <name>ProfileDialog</name>
