@@ -1,19 +1,8 @@
 /**************************************************************************
  *                                                                        *
- * Copyright (C) 2015 Felix Rohrbach <kde@fxrh.de>                        *
+ * SPDX-FileCopyrightText: 2015 Felix Rohrbach <kde@fxrh.de>              *
  *                                                                        *
- * This program is free software; you can redistribute it and/or          *
- * modify it under the terms of the GNU General Public License            *
- * as published by the Free Software Foundation; either version 3         *
- * of the License, or (at your option) any later version.                 *
- *                                                                        *
- * This program is distributed in the hope that it will be useful,        *
- * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the          *
- * GNU General Public License for more details.                           *
- *                                                                        *
- * You should have received a copy of the GNU General Public License      *
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.  *
+ * SPDX-License-Identifier: GPL-3.0-or-later
  *                                                                        *
  **************************************************************************/
 
@@ -26,10 +15,11 @@
 #include <QtWidgets/QInputDialog>
 #include <QtGui/QGuiApplication>
 
-#include <connection.h>
-#include <events/roompowerlevelsevent.h>
-#include <room.h>
-#include <user.h>
+#include <Quotient/connection.h>
+#include <Quotient/events/roompowerlevelsevent.h>
+#include <Quotient/room.h>
+#include <Quotient/user.h>
+
 #include "models/userlistmodel.h"
 #include "quaternionroom.h"
 
@@ -125,8 +115,9 @@ void UserListDock::showContextMenu(QPoint pos)
     contextMenu->addSeparator();
 
     const auto* plEvt =
-        m_currentRoom->getCurrentState<Quotient::RoomPowerLevelsEvent>();
-    int userPl = plEvt->powerLevelForUser(m_currentRoom->localUser()->id());
+        m_currentRoom->currentState().get<Quotient::RoomPowerLevelsEvent>();
+    const int userPl =
+        plEvt ? plEvt->powerLevelForUser(m_currentRoom->localUser()->id()) : 0;
 
     if (!plEvt || userPl >= plEvt->kick()) {
         contextMenu->addAction(QIcon::fromTheme("im-ban-kick-user"),
